%Evaporation Analysis Tool
%
%Functions  (a) read data from file as traing database
%           (b) fit Modified Hargreaves
%           (c) crossvalidation and plotting
%           (d) apply MH on new Input Data


%Introduction of functions:
%
%PM: PET = [(0.408 * Teta * (Rn-G) + gamma(900/(Tavg+273)) * u2* (es-ea)] /
%           Teta + gamma * (1 + 0.34*u2)

%MH: HET = 0.0013 * 0.408 * RA * (Tavg+17.0) * (TD-0.0123 P) ^ 0.76
%
%PM see kovoor06 page 11
%
%RA = Extraterrestial Radiation in MJ*m^2*d^1
%Tavg = mean Temperature
%TD = Temperature Range = Tmax-Tmin
%P = Precipitation



%#################################
%#   reading weather data        #
%#################################


clear;

%reading data from file tmax tmin EP Prec
fid = fopen('weatherXnonan.csv');
filestore = fscanf(fid,'%g %g %g %g %g\n',[5 inf]);
filestore = filestore';
fclose(fid)

day=filestore(:,1);
Tmax=filestore(:,2);
Tmin=filestore(:,3);
EP=filestore(:,5);
Prec=filestore(:,4);





%#################################
%#   terrestial radiation        #
%#################################

%parametrization after stull:
%Transmitted short wave radiation RA (check units; check daysum!!!)
%Kin = S * TK * sin(Psi)
%TK = (0.6 + 0.2 * sin(Psi)) * (1 - 0.4 * sigCH) * (1 - 0.7 * sigCM)
%      * (1 - 0.4 * sigCL)
%sin(Psi) = sin(LAT)*sin(SDA) - cos(LAT)*cos(SDA)*cos [((pi*tUTC)/12)-LON]
%SDA = ToC * cos { [2*pi*(d-dr)] / dy}

%ToC=23.45=0.409rad
%d<-day of the year
%dr<-day of summer solstice=173
%dy<-no. of days in year=365.25



%parametrization after chuanyan et. al (clouds not considered here!)
%PET=0.0023*S0*dT*(Tmean+17.8)
%thus S0=0.408*RA
%
%---> substitute S0 in modified Hargreaves:
%PET= 0.0013 * S0 * (Tmean+17.0) * (dT - (0.0123 * P))^0.76
%S0= 15.392 * dr * (t * sin(LAT) * sin(decl) + cos(LAT) * cos(decl) * sin(t))
%dr= 1 + 0.033 * cos((2*pi)/(365*J))
%t= arccos(-tan(LAT) * tan(decl))
%decl= 0.4093 * sin(((2*pi)/365)*J - 1.405)
%      ''''''
%       ToC


% ################ PARAMETERS ################

LAT=22.4;
%LON=-74.3*pi/180;
%ToC=23.45*pi/180;
S=1370;%W/m^2; Kyle 1985
cor1=-5.7507;

% ## CALCULATION OF LOOK-UP TABLE FOR S0 #####

d=1

for d=1:365
	%chuanyan paramerization
    decl = 0.4093 * sin(((2*pi)/365)*d - 1.405);
    dr = 1 + 0.033 * cos((2*pi)/(365*d));
    t= acos(-tan(LAT) * tan(decl));
    S0(d)= 15.392 * dr * (t * sin(LAT) * sin(decl) + cos(LAT) * cos(decl) * sin(t));
    %MJ/m2/d

    %stull parametrization
    SDA = 0.4093 * cos([2*pi*(d-173)]/365);
    sP = sin(LAT)*sin(SDA) - cos(LAT)*cos(SDA); %*cos [((pi*tUTC)/12)-LON] seems to be downscaling below day
    TKsun = (0.6 + 0.2 * sP);
    TKcloud = (0.6 + 0.2 * sP) * (1 - 0.4 * 0.8) * (1 - 0.7 * 0.8) * (1 - 0.4 * 0.8);
    TKmed = (0.6 + 0.2 * sP) * (1 - 0.4 * 0.3) * (1 - 0.7 * 0.3) * (1 - 0.4 * 0.3);
    RA(1,d) = S * TKsun * sP * (1e-6)*(24*60*60) /cor1;
    RA(2,d) = S * TKmed * sP * (1e-6)*(24*60*60) /cor1;
    RA(3,d) = S * TKcloud * sP * (1e-6)*(24*60*60) /cor1;
    %W/m2
end

betan=15.4;
alphan=2.9;
deltan=9.6;

% #### PARATETRIZATION OF MOD HARGREAVES #####


    %#################################
    %#   Hargreaves Modified         #
    %#################################

    % HET = 0.0013 * S0 * (Tavg + 17.0) * (TD-0.0123 P) ^ 0.76
    %       ''''''                ''''
    %       fitting              fitting



    i=2;
    w1=0.5;
    w2=1-w1;
    betay=betan;
    gammay=alphan;
    deltay=deltan;

    % Calculating Hargreaves (PET) and modified Hargreves (HET)

    for i=2:(length(Tmax)-1)

        %### CALCULATION #######

        TP = (Tmax(i)-Tmin(i)) - (0.0123 * Prec(i));
        if TP<0
            TP=0;
        end
        Tmean=mean([Tmax(i) Tmin(i)]);
        %after chuanyan/droogers
        HETc(i) = 0.0013 * S0(day(i)) * (exp((Tmean/gammay)-deltay) + (w1*Tmax(i) + w2*Tmin(i)) + betay) * ((TP) ^ 0.76);%introduce weighted means
        PETc(i) = 0.0023 * S0(day(i)) * ((Tmax(i)-Tmin(i)) ^ 0.5) * ((w1*Tmax(i) + w2*Tmin(i)) + 17.8);

        %modify radiation for clouds estimated from precipitation on day
        %and day before
        if Prec(i)>30 %cloudy
            Smod=S0(day(i))*(1 - 0.4 * 0.8) * (1 - 0.7 * 0.8) * (1 - 0.4 * 0.8); %modified approach after stull to cloud effect parameterisation
        elseif (Prec(i-1)+Prec(i)+Prec(i+1))<10 %relatively sunny
            Smod=S0(day(i));
        else Smod=S0(day(i))* (1 - 0.4 * 0.2) * (1 - 0.7 * 0.2) * (1 - 0.4 * 0.2); %medium partly cloudy
        end

        HETcm(i) = 0.0013 * Smod * (exp((Tmean/gammay)-deltay) + (w1*Tmax(i) + w2*Tmin(i)) + betay) * ((TP) ^ 0.76);

        %after stull/droogers
        if Prec(i)>20                %estimating clouds
            RAD=RA(3,day(i));
        elseif (Prec(i-1)+Prec(i)+Prec(i+1))<8
            RAD=RA(1,day(i));
        else RAD=RA(2,day(i));
        end
        HETs(i) = 0.0013 * RAD * (1.3*(w1*Tmax(i) + w2*Tmin(i)) + 8.5) * ((TP) ^ 0.76);
        PETs(i) = 0.0023 * RAD * ((Tmax(i)-Tmin(i)) ^ 0.5) * ((w1*Tmax(i) + w2*Tmin(i)) + 17.8);

        %### COMPARISON ########

        div(1,i)= EP(i) + HETc(i); %positive because of negative HET
        div(2,i)= EP(i) + PETc(i);
        div(3,i)= EP(i) + HETcm(i);
        div(4,i)= EP(i) + HETs(i);
        div(5,i)= EP(i) + PETs(i);

    end

    figure(1)
    plot(HETc,'Color','blue');
    hold on
    plot(HETcm,'Color','red');


    % %### PARAMETER FITTING ######
    %     %alpha and beta are to be fitted at HETc and HETs; apply to unmod.
    %     %Hargreaves if necessary, too.
    %
    % % PARAMETER SEEDS
    %
    % alpha=ones(length(Tmax),1)*gammay;
    % beta=ones(length(Tmax),1)*betay;
    % iter=100; %max. iterations per step
    % acc=0.05; %accuracy of fitting
    % j=1;
    %
    %
    % x=randperm(length(Tmax));
    %
    %    for j=1:(length(Tmax)/2) %using half set from input
    %        i=x(j);
    %        if i==1 | i==length(Tmax) %avoid matrix exceed
    %            i=2;
    %        end
    %     dHcm=div(1,i); %seed from calculation into temp memory
    % %    dHsm=div(3,i);
    %     stop=1;
    %     counter=1;
    %     alphaa=gammay;
    %     betaa=betay;
    %     deltaa=deltay;
    %
    %     while stop>0;
    %     alphax(1)=alphaa;
    %     alphax(2)=alphaa-0.5;
    %     alphax(3)=alphaa+0.5;
    %     betax(1)=betaa;
    %     betax(2)=betaa-0.05;
    %     betax(3)=betaa+0.05;
    %     deltax(1)=deltaa;
    %     deltax(2)=deltaa-0.05;
    %     deltax(3)=deltaa+0.05;
    %
    %     m=1;
    %     k=1;
    %     l=1;
    %     for m=1:3
    %     for k=1:3
    %     for l=1:3
    %
    %     %#### CALCULATION CORE #########
    %     TP = (Tmax(i)-Tmin(i)) - (0.0123 * Prec(i));
    %     if TP<0
    %         TP=0;
    %     end
    %     Tmean=mean([Tmax(i) Tmin(i)]);
    %     %after chuanyan/droogers
    %     HETcx(m,k,l) = 0.0013 * S0(day(i)) * (exp((Tmean/alphax(k))-deltax(m)) + (w1*Tmax(i) + w2*Tmin(i)) + betax(l)) * ((TP) ^ 0.76);
    %     dHc(m,k,l) = EP(i) + HETcx(m,k,l);
    %
    %     %after stull/droogers
    % %        if Prec(i)>20                %estimating clouds
    % %          RAD=RA(3,day(i));
    % %        elseif (Prec(i-1)+Prec(i)+Prec(i+1))<8
    % %          RAD=RA(1,day(i));
    % %        else RAD=RA(2,day(i));
    % %        end
    % %    HETsx(k) = alphax(k) * RAD * (mean([Tmax(i) Tmin(i)]) + betax(l)) * ((TP) ^ 0.76);
    % %    dHs(k,l) = EP(i) + HETsx(k,l);
    %     %#### END CALCULATION CORE #####
    %
    %     end
    %     end
    %     end
    %
    %     %### COMPARE RESULTS ###
    %     if abs(min(min(min(dHc))))<abs(dHcm)
    %     for m=1:3
    %     for k=1:3
    %     for l=1:3
    %         if abs(dHc(m,k,l))==min(min(min(abs(dHc))))
    %             alphaa=alphax(k);
    %             betaa=betax(l);
    %             deltaa=deltax(m);
    %             dHcm=dHc(k,l);
    %         end
    %     end
    %     end
    %     end
    %     elseif counter>iter | abs(min(min(min(dHc))))<acc
    %          stop=-1;
    %
    %     end
    %     counter=counter+1;
    %     dHcm=dHc;
    %     end %end of while
    %
    %     alpha(i)=alphaa;
    %     beta(i)=betaa;
    %     delta(i)=deltaa;
    %     alphas(j)=alphaa;
    %     betas(j)=betaa;
    %     deltas(j)=deltaa;
    %
    %    end
    %
    %   %#### END OF PARAMETER FITTING ##############
    %
    %   %#### APPLICATION TO OTHER HALF #############
    %   alphan=mean([alphan median(alphas)]);
    %   betan=mean([betan median(betas)]);
    %   deltan=mean([deltan median(deltas)]);
    %   j=round(length(Tmax)/2);
    %   n=0;
    %
    %   for j=round(length(Tmax)/2):length(Tmax) %using all set from input
    %        i=x(j);
    %        n=n+1;
    %        if i==1 | i==length(Tmax) %avoid matrix exceed
    %            i=2;
    %        end
    %
    %     %#### CALCULATION CORE #########
    %     TP = (Tmax(i)-Tmin(i)) - (0.0123 * Prec(i));
    %     if TP<0
    %         TP=0;
    %     end
    %     Tmean=mean([Tmax(i) Tmin(i)]);
    %     %after chuanyan/droogers
    %     HETcn(i) = 0.0013 * S0(day(i)) * (exp((Tmean/alphan)-deltan) + (w1*Tmax(i) + w2*Tmin(i)) + betan) * ((TP) ^ 0.76);
    %     dHcn(1,n) = EP(i) + HETcn(i);
    %     dHcn(2,n) = EP(i) + HETc(i);
    %     dHcn(3,n) = abs(dHcn(2,n)) - abs(dHcn(1,n));
    %
    %     %#### END CALCULATION CORE #####
    %
    %   end
    %
    %   diff(1,v)=alphan;
    %   diff(2,v)=betan;
    %   diff(3,v)=deltan;
    %   diff(4,v)=sum(abs(dHcn(1,:)));
    %   diff(5,v)=sum(abs(dHcn(2,:)));
    %   diff(6,v)=sum(abs(dHcn(3,:)));
    %   diff(7,v)=sum(abs(HETc))-sum(EP);
    %
    % end
    
% i=1;
% fid = fopen('hargreaves_fit_new.csv','w');
% fprintf(fid,['alpha:' num2str(alphan) ' beta:' num2str(betan) ' delta:' num2str(deltan) '\n'])
% fprintf(fid,'day HETc HETcm Tmax Tmin Prec ET\n')
% for i=1:length(HETc)
%     pr=[day(i) HETc(i) HETcm(i) Tmax(i) Tmin(i) Prec(i) EP(i)];
%     fprintf(fid,'%g %3.2f %3.2f %3.2f %3.2f %3.2f %3.2f \n',pr);
% end
% fclose(fid)

