################################################
# WASA simulation result analysis tool using R #
################################################

#for the software and toolboxes check www.r-project.org

#TARGET: > analyze a set of output files from WASA for interpretation
#		     > derive a ranking for the agents' performance after certain hydrologic aspects
#		     > keep most of the information of the datasets in least variables

#version 1.3
#CC conrad jackisch, Feb. 2007
#   institute for geoecology, university potsdam, germany
#   jackisch@uni-potsdam.de

#WARNING!!! THIS SCRIPT MIGHT NOT RUN AS ONE ON EVERY MACHINE AS IT WILL NEED TO ALLOCATE
#SEVERAL GIGABYTES OF DATA WHICH LIKELY WILL NOT FIT THE PROVIDED STORAGE. CONSIDER TO USE
#THE FUNCTIONS STEPWISE FOR DATA PROCESSING. STILL IT MIGHT TAKE YOU SEVERAL DAYS TO PERFORM
#THIS ANALYSIS...


#initialize wasastat-function to be used
wasastat<-function(homedir,AGENT,WEATHER,doutfile){

Fharvest=paste(homedir,'output/tcwise_harvest.out',sep='');
Fdischarge=paste(homedir,'output/River_Flow.out',sep='');
Fprecip=paste(homedir,'input/Time_series/rain_daily.dat',sep='');
Ftheta=paste(homedir,'output/daily_theta.out',sep='');
Foverland=paste(homedir,'output/daily_total_overlandflow.out',sep='');
Fsubsurf=paste(homedir,'output/daily_subsurface_runoff.out',sep='');
Fetp=paste(homedir,'output/daily_actetranspiration.out',sep='');
goutfile1=paste(homedir,'graphic',sep='');

#routine

harvest<-read.table(Fharvest,skip=2,header=F,na.string='NaN')
harvest[is.na(harvest)]=1
#read in tc_wise harvest data
#V1>year V2>SUB V3>LU V4>TC V5>SVC V6>season V7>area V8>share V9>crop V10>input V11>gains V12>harvest

discharge<-read.table(Fdischarge,skip=2,header=F,na.string='NaN')
#read in tc_wise discharge data
#V1>year V2>day V67>flow at outlet m3/s

precip<-read.table(Fprecip,skip=3,header=F,na.string='NaN')
#read in tc_wise precipitation data
#year>V1-(trunc(V1/10000))*10000 V2>day V3..V66>precipitation mm
precip$V1<-precip$V1-(trunc(precip$V1/10000))*10000

overland<-read.table(Foverland,skip=2,header=F,na.string='NaN')
#read in tc_wise total overland flow data
#V1>year V2>day V3..V66>overland flow in m3/d

subsurf<-read.table(Fsubsurf,skip=2,header=F,na.string='NaN')
#read in tc_wise total subsurface flow data
#V1>year V2>day V3..V66>subsurface flow in m3/d

etp<-read.table(Fetp,skip=2,header=F,na.string='NaN')
etp[is.na(etp)]=0
#read in actual etp
#V1>year V2>day V3..V66>etp in mm/d

theta<-read.table(Ftheta,skip=2,header=F,na.string='NaN')
#read in tc_wise total theta data
#V1>year V2>day V3..V66>theta in mm

years<-unique(harvest$V1)
XXL=matrix(ncol=82,nrow=(length(years)*2),data=0)

start=0 #use this for index adjustment

for(i in 1:length(years)) {
							#PHYSICAL PARAMETERS
							prec_m=mean(subset(precip$V4,precip$V1==years[i]))
							prec_mt=mean(subset(precip$V4,precip$V1==years[i] & precip$V4>0))
							prec_v=var(subset(precip$V4,precip$V1==years[i]))
							prec_vt=var(subset(precip$V4,precip$V1==years[i] & precip$V4>0))
							prec_mx=max(subset(precip$V4,precip$V1==years[i]))
							prec_s=sum(subset(precip$V4,precip$V1==years[i]))
							prec_x=length(subset(precip$V4,precip$V1==years[i] & precip$V4>0))
							
							dis_m=mean(subset(discharge$V67,discharge$V1==years[i]))
							dis_mt=mean(subset(discharge$V67,discharge$V1==years[i] & discharge$V67>0.))
							dis_v=var(subset(discharge$V67,discharge$V1==years[i]))
							dis_vt=var(subset(discharge$V67,discharge$V1==years[i] & discharge$V67>0.))
							dis_mx=max(subset(discharge$V67,discharge$V1==years[i]))
							dis_s=sum(subset(discharge$V67,discharge$V1==years[i]))
							dis_x=length(subset(discharge$V67,discharge$V1==years[i] & discharge$V67>0.))
							
							sub_m=mean(mean(subset(subsurf[,3:66],subsurf[,1]==years[i])))
							sub_v=median(var(subset(subsurf[,3:66],subsurf[,1]==years[i])))
							sub_mx=max(subset(subsurf[,3:66],subsurf[,1]==years[i]))
							sub_s=sum(subset(subsurf[,3:66],subsurf[,1]==years[i]))
							
							over_m=mean(mean(subset(overland[,3:66],overland[,1]==years[i])))
							over_v=median(var(subset(overland[,3:66],overland[,1]==years[i])))
							over_mx=max(subset(overland[,3:66],overland[,1]==years[i]))
							over_s=sum(subset(overland[,3:66],overland[,1]==years[i]))
							
							#theta not yet regarded
							
							etp_m=mean(mean(subset(etp[,3:66],etp[,1]==years[i])))
							etp_v=median(var(subset(etp[,3:66],etp[,1]==years[i])))
							etp_mx=max(subset(etp[,3:66],etp[,1]==years[i]))
							etp_mn=min(subset(etp[,3:66],etp[,1]==years[i]))
							
							#HARVEST REGARDS
							harvk_sub<-subset(harvest,harvest$V1==years[i] & harvest$V6==1)
							harvr_sub<-subset(harvest,harvest$V1==years[i] & harvest$V6==2)
							cropsk<-unique(harvk_sub[,9])
							cropsr<-unique(harvr_sub[,9])
							harvk_sub[,12][harvk_sub[,12]<0]=0
							harvr_sub[,12][harvr_sub[,12]<0]=0
							harvk_sub[,12][harvk_sub[,12]>10000]=harvk_sub[,12][harvk_sub[,12]>10000] - trunc(harvk_sub[,12][harvk_sub[,12]>10000]/10000)*10000
							harvr_sub[,12][harvr_sub[,12]>10000]=harvr_sub[,12][harvr_sub[,12]>10000] - trunc(harvr_sub[,12][harvr_sub[,12]>10000]/10000)*10000
							
							
							#kharif
							harv_ak<-numeric(length(cropsk)) 	#harvested amount of crops
							harv_rk<-harv_ak					#area cropped
							harv_ik<-harv_ak					#inputs
							harv_gk<-harv_ak					#gains
							for(ii in 1:length(cropsk)) {
															#flick through crops in season of year to analyse shares and patterns
															harv_ak[ii]<-subset(harvk_sub[,12],harvk_sub[,9]==cropsk[ii])%*%subset(harvk_sub[,7],harvk_sub[,9]==cropsk[ii])
															harv_rk[ii]<-sum(subset(harvk_sub[,7],harvk_sub[,9]==cropsk[ii]))
															harv_ik[ii]<-mean(subset(harvk_sub[,10],harvk_sub[,9]==cropsk[ii]))
															harv_gk[ii]<-mean(subset(harvk_sub[,11],harvk_sub[,9]==cropsk[ii]))
															}
							
							#rabi
							harv_ar<-numeric(length(cropsr)) 	#harvested amount of crops
							harv_rr<-harv_ar					#area cropped
							harv_ir<-harv_ar					#inputs
							harv_gr<-harv_ar					#gains
							for(ii in 1:length(cropsr)) {
															#flick through crops in season of year to analyse shares and patterns
															harv_ar[ii]<-subset(harvr_sub[,12],harvr_sub[,9]==cropsr[ii])%*%subset(harvr_sub[,7],harvr_sub[,9]==cropsr[ii])
															harv_rr[ii]<-sum(subset(harvr_sub[,7],harvr_sub[,9]==cropsr[ii]))
															harv_ir[ii]<-mean(subset(harvr_sub[,10],harvr_sub[,9]==cropsr[ii]))
															harv_gr[ii]<-mean(subset(harvr_sub[,11],harvr_sub[,9]==cropsr[ii]))
															}
							
							idx=start+i*2
							
							#STORE RESULTS IN MATRIX
							XXL[(idx-1):idx,1]=AGENT
							XXL[(idx-1):idx,2]=WEATHER
							XXL[(idx-1):idx,3]=years[i]
							XXL[(idx-1):idx,4]=c(1,2)
							XXL[(idx-1):idx,5]=prec_m
							XXL[(idx-1):idx,6]=prec_mt
							XXL[(idx-1):idx,7]=prec_v
							XXL[(idx-1):idx,8]=prec_vt
							XXL[(idx-1):idx,9]=prec_mx
							XXL[(idx-1):idx,10]=prec_s
							XXL[(idx-1):idx,11]=prec_x
							XXL[(idx-1):idx,12]=dis_m
							XXL[(idx-1):idx,13]=dis_mt
							XXL[(idx-1):idx,14]=dis_v
							XXL[(idx-1):idx,15]=dis_vt
							XXL[(idx-1):idx,16]=dis_mx
							XXL[(idx-1):idx,17]=dis_s
							XXL[(idx-1):idx,18]=dis_x
							XXL[(idx-1):idx,19]=sub_m
							XXL[(idx-1):idx,20]=sub_v
							XXL[(idx-1):idx,21]=sub_mx
							XXL[(idx-1):idx,22]=sub_s
							XXL[(idx-1):idx,23]=over_m
							XXL[(idx-1):idx,24]=over_v
							XXL[(idx-1):idx,25]=over_mx
							XXL[(idx-1):idx,26]=over_s
							XXL[(idx-1):idx,27]=etp_m
							XXL[(idx-1):idx,28]=etp_v
							XXL[(idx-1):idx,29]=etp_mx
							XXL[(idx-1):idx,30]=etp_mn
							
							#crop values now
							XXL[idx-1,cropsk+30]=harv_rk
							XXL[idx-1,cropsk+43]=harv_ak
							XXL[idx-1,cropsk+56]=harv_ik			
							XXL[idx-1,cropsk+69]=harv_gk
							
							XXL[idx,cropsr+30]=harv_rr
							XXL[idx,cropsr+43]=harv_ar
							XXL[idx,cropsr+56]=harv_ir			
							XXL[idx,cropsr+69]=harv_gr
							
							
							#plot yearly overview
							goutfile=paste(goutfile1,i,'.eps',sep='');
							postscript(goutfile,width=8,height=10,horizontal=FALSE,paper='a4')
								par(mfrow=c(4,1))
								ts.plot(subset(precip$V4,precip$V1==years[i]),main=paste('WASA Simulations - Agent: ',AGENT,'; Weather: ',WEATHER,'; on year: ',years[i],' - PRECIPITATION',sep=''),xlab='day',ylab='mm')
								ts.plot(subset(discharge$V67,discharge$V1==years[i]),main=paste('WASA Simulations - Agent: ',AGENT,'; Weather: ',WEATHER,'; on year: ',years[i],' - DISCHARGE',sep=''),xlab='day',ylab='m3/s')
								plot(as.factor(harvk_sub[,9]),harvk_sub[,12],notch=T,main=paste('WASA Simulations - Agent: ',AGENT,'; Weather: ',WEATHER,'; on year: ',years[i],' - HARVEST KHARIF',sep=''),xlab='crop',ylab='kg/ha')
								plot(as.factor(harvr_sub[,9]),harvr_sub[,12],notch=T,main=paste('WASA Simulations - Agent: ',AGENT,'; Weather: ',WEATHER,'; on year: ',years[i],' - HARVEST RABI',sep=''),xlab='crop',ylab='kg/ha')
								
							dev.off()
							
							} #end of year		
		
write.table(XXL, file=doutfile, append=TRUE, quote=FALSE, sep='\t', row.names=FALSE, col.names=FALSE)
} #end of wasastat-function

##################
#initialize Rain-Runoff-Variance preparation-function
RRVprep<-function(homedir,AGENT,WEATHER){

Fharvest=paste(homedir,'output/tcwise_harvest.out',sep='');
Fdischarge=paste(homedir,'output/River_Flow.out',sep='');
Fprecip=paste(homedir,'input/Time_series/rain_daily.dat',sep='');
Ftheta=paste(homedir,'output/daily_theta.out',sep='');
Foverland=paste(homedir,'output/daily_total_overlandflow.out',sep='');
Fsubsurf=paste(homedir,'output/daily_subsurface_runoff.out',sep='');
Fetp=paste(homedir,'output/daily_actetranspiration.out',sep='');
goutfile1=paste(homedir,'graphic',sep='');

#routine

harvest<-read.table(Fharvest,skip=2,header=F,na.string='NaN')
harvest[is.na(harvest)]=1
#read in tc_wise harvest data
#V1>year V2>SUB V3>LU V4>TC V5>SVC V6>season V7>area V8>share V9>crop V10>input V11>gains V12>harvest

discharge<-read.table(Fdischarge,skip=2,header=F,na.string='NaN')
#read in tc_wise discharge data
#V1>year V2>day V67>flow at outlet m3/s

precip<-read.table(Fprecip,skip=3,header=F,na.string='NaN')
#read in tc_wise precipitation data
#year>V1-(trunc(V1/10000))*10000 V2>day V3..V66>precipitation mm
precip$V1<-precip$V1-(trunc(precip$V1/10000))*10000

overland<-read.table(Foverland,skip=2,header=F,na.string='NaN')
#read in tc_wise total overland flow data
#V1>year V2>day V3..V66>overland flow in m3/d

subsurf<-read.table(Fsubsurf,skip=2,header=F,na.string='NaN')
#read in tc_wise total subsurface flow data
#V1>year V2>day V3..V66>subsurface flow in m3/d

etp<-read.table(Fetp,skip=2,header=F,na.string='NaN')
etp[is.na(etp)]=0
#read in actual etp
#V1>year V2>day V3..V66>etp in mm/d

theta<-read.table(Ftheta,skip=2,header=F,na.string='NaN')
#read in tc_wise total theta data
#V1>year V2>day V3..V66>theta in mm

years<-unique(harvest$V1)

for(i in 1:length(years)) {
							Aprec<-subset(precip$V4,precip$V1==years[i])
							Adis<-subset(discharge[,3:66],discharge[,1]==years[i])
							Asub<-subset(subsurf[,3:66],subsurf[,1]==years[i])
							Aover<-subset(overland[,3:66],overland[,1]==years[i])
							Aetp<-subset(etp[,3:66],etp[,1]==years[i])
							Atheta<-subset(theta[,3:66],theta[,1]==years[i])
							
							
							idx<-matrix(c(AGENT,WEATHER),length(Adis[,1]),2,byrow=T)
							
							#d2outfile='./Xprec',years[i],'w',WEATHER,'.dat',sep='')
							#write.table(cbind(idx,Aprec), file=d2outfile, append=TRUE, quote=FALSE, sep='\t', row.names=FALSE, col.names=FALSE)
							d2outfile=paste('./Xdis',years[i],'w',WEATHER,'.dat',sep='')
							write.table(cbind(idx,Adis), file=d2outfile, append=TRUE, quote=FALSE, sep='\t', row.names=FALSE, col.names=FALSE)
							d2outfile=paste('./Xsub',years[i],'w',WEATHER,'.dat',sep='')
							write.table(cbind(idx,Asub), file=d2outfile, append=TRUE, quote=FALSE, sep='\t', row.names=FALSE, col.names=FALSE)
							d2outfile=paste('./Xover',years[i],'w',WEATHER,'.dat',sep='')
							write.table(cbind(idx,Aover), file=d2outfile, append=TRUE, quote=FALSE, sep='\t', row.names=FALSE, col.names=FALSE)
							d2outfile=paste('./Xetp',years[i],'w',WEATHER,'.dat',sep='')
							write.table(cbind(idx,Aetp), file=d2outfile, append=TRUE, quote=FALSE, sep='\t', row.names=FALSE, col.names=FALSE)
							d2outfile=paste('./Xtheta',years[i],'w',WEATHER,'.dat',sep='')
							write.table(cbind(idx,Atheta), file=d2outfile, append=TRUE, quote=FALSE, sep='\t', row.names=FALSE, col.names=FALSE)
							
							}
} #end of RRV-prep function

###############
#initialize Rainfall-Runoff-Variance function
RRV<-function(year,WEATHER) {

#d2outfile='./Xprec',year,'w',WEATHER,'.dat',sep='')
#Xprec<-read.table(d2outfile, header=F, sep='\t')
d2outfile=paste('./Xdis',year,'w',WEATHER,'.dat',sep='')
Xdis<-read.table(d2outfile, header=F, sep='\t')
d2outfile=paste('./Xsub',year,'w',WEATHER,'.dat',sep='')
Xsub<-read.table(d2outfile, header=F, sep='\t')
d2outfile=paste('./Xover',year,'w',WEATHER,'.dat',sep='')
Xover<-read.table(d2outfile, header=F, sep='\t')
d2outfile=paste('./Xetp',year,'w',WEATHER,'.dat',sep='')
Xetp<-read.table(d2outfile, header=F, sep='\t')
d2outfile=paste('./Xtheta',year,'w',WEATHER,'.dat',sep='')
Xtheta<-read.table(d2outfile, header=F, sep='\t')
 
#get mean behavior
Mdis=matrix(0,365,64)
Msub=matrix(0,365,64)
Mover=matrix(0,365,64)
Metp=matrix(0,365,64)
Mtheta=matrix(0,365,64)
Ddis=matrix(0,365,64)
Dsub=matrix(0,365,64)
Dover=matrix(0,365,64)
Detp=matrix(0,365,64)
Dtheta=matrix(0,365,64)
idx<-numeric(9)
for(i in 2:9) idx[i]=idx[i-1]+365

for(i in 1:365) {
					Mdis[i,]<-apply(Xdis[idx+1,3:66],2,function(x) mean(x,na.rm=T))
					Msub[i,]<-apply(Xsub[idx+1,3:66],2,function(x) mean(x,na.rm=T))
					Mover[i,]<-apply(Xover[idx+1,3:66],2,function(x) mean(x,na.rm=T))
					Metp[i,]<-apply(Xetp[idx+1,3:66],2,function(x) mean(x,na.rm=T))
					Mtheta[i,]<-apply(Xtheta[idx+1,3:66],2,function(x) mean(x,na.rm=T))
					Ddis[i,]<-apply(Xdis[idx+1,3:66],2,function(x) sd(x,na.rm=T))
					Dsub[i,]<-apply(Xsub[idx+1,3:66],2,function(x) sd(x,na.rm=T))
					Dover[i,]<-apply(Xover[idx+1,3:66],2,function(x) sd(x,na.rm=T))
					Detp[i,]<-apply(Xetp[idx+1,3:66],2,function(x) sd(x,na.rm=T))
					Dtheta[i,]<-apply(Xtheta[idx+1,3:66],2,function(x) sd(x,na.rm=T))
				}

#compare realisations to mean
#for each SUB it will be calculated: Reliability
for(ii in 1:9) { 
				ACMs<-matrix(0,50,64)	
				#1absolute deviance from mean
				#2deviance from mean
				#3days above bound
				#4days beyond bound
				#5bove bound deviance
				#6beyond bound deviance
				#7max continuous days above bounds
				#8max continuous days beyond bounds
			 	#9mean continous days above bound
 				#10mean continous days beyond bound
			
				#discharge
				cmx<-Mdis-subset(Xdis[,3:66],Xdis[,1]==i) 	#comparison matrix
				cmx[abs(cmx)<abs(Ddis)]=0					#set zero dev. if inside sd
				abmx<-cmx/abs(cmx)							#above/beyond means
				
				ACMs[1,]<-apply(cmx,2,function(x) sum(abs(x),na.rm=T))
				ACMs[2,]<-apply(cmx,2,function(x) sum(x,na.rm=T))
				ACMs[3,]<-apply(abmx,2,function(x) sum(x[x>0 & !is.na(x)]))
				ACMs[4,]<-apply(abmx,2,function(x) sum(abs(x[x<0 & !is.na(x)])))
				ACMs[5,]<-apply(cmx,2,function(x) sum(abs(x[x>0 & !is.na(x)]),na.rm=T))
				ACMs[6,]<-apply(cmx,2,function(x) sum(abs(x[x<0 & !is.na(x)]),na.rm=T))
				
				abmx[is.na(abmx)]=0
				for(m in 1:64){
					k=1
					l=1
					above<-numeric(1)
					above=0
					beyond<-above
					for(i in 2:365) {
										if(abmx[i-1,m]>0 && abmx[i,m]>0) above[k]=above[k]+1 else k=k+1
										if(abmx[i-1,m]<0 && abmx[i,m]<0) beyond[l]=beyond[l]+1 else l=l+1
									}
					ACMs[7,m]<-max(above,na.rm=T)
					ACMs[8,m]<-max(beyond,na.rm=T)
					
					ACMs[9,m]<-mean(above[above>0 & !is.na(above)])
					ACMs[10,m]<-mean(beyond[beyond>0 & !is.na(beyond)])
								}
								
				#subflow				
				cmx<-Msub-subset(Xsub[,3:66],Xsub[,1]==i) 	#comparison matrix
				cmx[abs(cmx)<abs(Dsub)]=0					#set zero dev. if inside sd
				abmx<-cmx/abs(cmx)							#above/beyond means
				
				ACMs[11,]<-apply(cmx,2,function(x) sum(abs(x),na.rm=T))
				ACMs[12,]<-apply(cmx,2,function(x) sum(x,na.rm=T))
				ACMs[13,]<-apply(abmx,2,function(x) sum(x[x>0 & !is.na(x)]))
				ACMs[14,]<-apply(abmx,2,function(x) sum(abs(x[x<0 & !is.na(x)])))
				ACMs[15,]<-apply(cmx,2,function(x) sum(abs(x[x>0 & !is.na(x)]),na.rm=T))
				ACMs[16,]<-apply(cmx,2,function(x) sum(abs(x[x<0 & !is.na(x)]),na.rm=T))
				
				abmx[is.na(abmx)]=0
				for(m in 1:64){
					k=1
					l=1
					above<-numeric(1)
					above=0
					beyond<-above
					for(i in 2:365) {
										if(abmx[i-1,m]>0 && abmx[i,m]>0) above[k]=above[k]+1 else k=k+1
										if(abmx[i-1,m]<0 && abmx[i,m]<0) beyond[l]=beyond[l]+1 else l=l+1
									}
					ACMs[17,m]<-max(above,na.rm=T)
					ACMs[18,m]<-max(beyond,na.rm=T)
					
					ACMs[19,m]<-mean(above[above>0 & !is.na(above)])
					ACMs[20,m]<-mean(beyond[beyond>0 & !is.na(beyond)])
								}
				
				#overland flow
				cmx<-Mover-subset(Xover[,3:66],Xover[,1]==i) 	#comparison matrix
				cmx[abs(cmx)<abs(Dover)]=0					#set zero dev. if inside sd
				abmx<-cmx/abs(cmx)							#above/beyond means
				
				ACMs[21,]<-apply(cmx,2,function(x) sum(abs(x),na.rm=T))
				ACMs[22,]<-apply(cmx,2,function(x) sum(x,na.rm=T))
				ACMs[23,]<-apply(abmx,2,function(x) sum(x[x>0 & !is.na(x)]))
				ACMs[24,]<-apply(abmx,2,function(x) sum(abs(x[x<0 & !is.na(x)])))
				ACMs[25,]<-apply(cmx,2,function(x) sum(abs(x[x>0 & !is.na(x)]),na.rm=T))
				ACMs[26,]<-apply(cmx,2,function(x) sum(abs(x[x<0 & !is.na(x)]),na.rm=T))
				
				abmx[is.na(abmx)]=0
				for(m in 1:64){
					k=1
					l=1
					above<-numeric(1)
					above=0
					beyond<-above
					for(i in 2:365) {
										if(abmx[i-1,m]>0 && abmx[i,m]>0) above[k]=above[k]+1 else k=k+1
										if(abmx[i-1,m]<0 && abmx[i,m]<0) beyond[l]=beyond[l]+1 else l=l+1
									}
					ACMs[27,m]<-max(above,na.rm=T)
					ACMs[28,m]<-max(beyond,na.rm=T)
					
					ACMs[29,m]<-mean(above[above>0 & !is.na(above)])
					ACMs[30,m]<-mean(beyond[beyond>0 & !is.na(beyond)])
								}
								
				#evapotranspiration
				cmx<-Metp-subset(Xetp[,3:66],Xetp[,1]==i) 	#comparison matrix
				cmx[abs(cmx)<abs(Detp)]=0					#set zero dev. if inside sd
				abmx<-cmx/abs(cmx)							#above/beyond means
				
				ACMs[31,]<-apply(cmx,2,function(x) sum(abs(x),na.rm=T))
				ACMs[32,]<-apply(cmx,2,function(x) sum(x,na.rm=T))
				ACMs[33,]<-apply(abmx,2,function(x) sum(x[x>0 & !is.na(x)]))
				ACMs[34,]<-apply(abmx,2,function(x) sum(abs(x[x<0 & !is.na(x)])))
				ACMs[35,]<-apply(cmx,2,function(x) sum(abs(x[x>0 & !is.na(x)]),na.rm=T))
				ACMs[36,]<-apply(cmx,2,function(x) sum(abs(x[x<0 & !is.na(x)]),na.rm=T))
				
				abmx[is.na(abmx)]=0
				for(m in 1:64){
					k=1
					l=1
					above<-numeric(1)
					above=0
					beyond<-above
					for(i in 2:365) {
										if(abmx[i-1,m]>0 && abmx[i,m]>0) above[k]=above[k]+1 else k=k+1
										if(abmx[i-1,m]<0 && abmx[i,m]<0) beyond[l]=beyond[l]+1 else l=l+1
									}
					ACMs[37,m]<-max(above,na.rm=T)
					ACMs[38,m]<-max(beyond,na.rm=T)
					
					ACMs[39,m]<-mean(above[above>0 & !is.na(above)])
					ACMs[40,m]<-mean(beyond[beyond>0 & !is.na(beyond)])
								}
				
				#theta
				cmx<-Mtheta-subset(Xtheta[,3:66],Xtheta[,1]==i) 	#comparison matrix
				cmx[abs(cmx)<abs(Dtheta)]=0					#set zero dev. if inside sd
				abmx<-cmx/abs(cmx)							#above/beyond means
				
				ACMs[41,]<-apply(cmx,2,function(x) sum(abs(x),na.rm=T))
				ACMs[42,]<-apply(cmx,2,function(x) sum(x,na.rm=T))
				ACMs[43,]<-apply(abmx,2,function(x) sum(x[x>0 & !is.na(x)]))
				ACMs[44,]<-apply(abmx,2,function(x) sum(abs(x[x<0 & !is.na(x)])))
				ACMs[45,]<-apply(cmx,2,function(x) sum(abs(x[x>0 & !is.na(x)]),na.rm=T))
				ACMs[46,]<-apply(cmx,2,function(x) sum(abs(x[x<0 & !is.na(x)]),na.rm=T))
				
				abmx[is.na(abmx)]=0
				for(m in 1:64){
					k=1
					l=1
					above<-numeric(1)
					above=0
					beyond<-above
					for(i in 2:365) {
										if(abmx[i-1,m]>0 && abmx[i,m]>0) above[k]=above[k]+1 else k=k+1
										if(abmx[i-1,m]<0 && abmx[i,m]<0) beyond[l]=beyond[l]+1 else l=l+1
									}
					ACMs[47,m]<-max(above,na.rm=T)
					ACMs[48,m]<-max(beyond,na.rm=T)
					
					ACMs[49,m]<-mean(above[above>0 & !is.na(above)])
					ACMs[50,m]<-mean(beyond[beyond>0 & !is.na(beyond)])
								}
				
				d2outfile='./compare.dat'
				idx=matrix(c(ii,WEATHER,year),50,3,byrow=T)
				write.table(cbind(idx,ACMs), file=d2outfile, append=TRUE, quote=FALSE, sep='\t', row.names=FALSE, col.names=FALSE)
							
				
			}
} #end of RRV function
	


				

					

#################
# START ROUTINE #
#################


abc<-c('a','b','c','d','e','f','g','h','i','j','k','l','m','p','q','r','s','t','u','v','w')
for(agent in 1:9) {
 for(weather in 1:21) {
   RRVprep(paste('./wasa',agent,abc[weather],'/',sep=''),agent,weather)
   print(paste('Done RRVprep for Agent',agent,'and Weather',abc[weather],'.'))
   }
  } 
print('Done RRVprep for all files')

for(year in 2000:2023) {
 for(weather in 1:21)     {
 	RRV(year,weather)
 	print(paste('Done RRV for year',year,'and Weather',abc[weather],'.'))
   }
 }
print('Done RRV for all files')



#get result from RRV function and assign indecees for further processing
ACM<-read.table('compare.dat',header=F)
idx<-c(1:50)
ACMx<-matrix(0,221550,68)
for(i in 1:4431){
ACMx[((i*50)-49):(i*50),]=cbind(idx,ACM[((i*50)-49):(i*50),])
}


####################
# AGENT ASSESSMENT #
####################


ACMx<-read.table('ACMx.dat',header=F)

#get overview about data range for each aspect
for(i in 1:50) {
                print(i)
                print(summary(subset(ACMx[,5:68],ACMx[,1]==i)))
                print('=======================================================')
                print(' ')
                }

agentrank<-matrix(0,45,64) #9*5=45
credits<-function(a) {  AA<-fivenum(a,na.rm=T)
                        BB<-numeric(9)
                        BB[a<AA[2]]=(-1) #below lower hinge
                        BB[a>AA[4]]=(1)    #above upper hinge
                        BB[a==max(a)]=(2)
                        BB[a==min(a)]=(-2)
                        BB[a>=AA[2] & a<=AA[4]]=0
                        BB
                        }
#compare all realisations -> e.g. credits for: few discharge, long period below mean, short above, dev/abs(dev)=1
 
for(i in 1:64){
                #DISCHARGE
                sortdummy<-matrix(0,9,10)
                sortdummy[,1]<-c(1:9)
                for(ii in 1:9) sortdummy[ii,2]=sum(ACMx[,i+4][ACMx[,1]==2 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==2 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,3]=credits(sortdummy[,2])
                #agents get points for decreased discharge at col. 3
                for(ii in 1:9) sortdummy[ii,4]=sum(ACMx[,i+4][ACMx[,1]==8 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==8 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,5]=credits(sortdummy[,4])
                #agents get credits for longest period below mean at col. 5
                for(ii in 1:9) sortdummy[ii,6]=sum(ACMx[,i+4][ACMx[,1]==7 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==7 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,7]=(-1)*credits(sortdummy[,6])
                #agents get credits for shortest period above mean at col. 7
                for(ii in 1:9){
                ad<-abs(ACMx[,i+4][ACMx[,1]==2 & ACMx[,2]==ii]/ACMx[,i+4][ACMx[,1]==1 & ACMx[,2]==ii]) #dev/abs(dev)
                ad[ad>1]=NA
                sortdummy[ii,8]=sum(ad,na.rm=T)/length(ad[!is.na(ad)])
                }
                sortdummy[,9]=credits(sortdummy[,8])
                #agents get credits for least fluctuation in terms of dev/abs(dev)=1
                sortdummy[,10]=apply(sortdummy[,c(3,5,7,9)],1,sum)
                
                agentrank[1:9,i]=sortdummy[,10]
                
                #SUBSURFACE FLOW * not considered
                
                #OVERLAND FLOW
                sortdummy<-matrix(0,9,10)
                sortdummy[,1]<-c(1:9)
                for(ii in 1:9) sortdummy[ii,2]=sum(ACMx[,i+4][ACMx[,1]==22 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==22 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,3]=credits(sortdummy[,2])
                #agents get points for decreased overland flow at col. 3
                for(ii in 1:9) sortdummy[ii,4]=sum(ACMx[,i+4][ACMx[,1]==28 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==28 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,5]=credits(sortdummy[,4])
                #agents get credits for longest period below mean at col. 5
                for(ii in 1:9) sortdummy[ii,6]=sum(ACMx[,i+4][ACMx[,1]==27 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==27 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,7]=(-1)*credits(sortdummy[,6])
                #agents get credits for shortest period above mean at col. 7
                for(ii in 1:9){
                ad<-abs(ACMx[,i+4][ACMx[,1]==22 & ACMx[,2]==ii]/ACMx[,i+4][ACMx[,1]==21 & ACMx[,2]==ii]) #dev/abs(dev)
                ad[ad>1]=NA
                sortdummy[ii,8]=sum(ad,na.rm=T)/length(ad[!is.na(ad)])
                }#agents get credits for least fluctuation in terms of dev/abs(dev)=1
                sortdummy[,10]=apply(sortdummy[,c(3,5,7,9)],1,sum)
                
                agentrank[19:27,i]=sortdummy[,10]
                
                #ETP
                sortdummy<-matrix(0,9,10)
                sortdummy[,1]<-c(1:9)
                for(ii in 1:9) sortdummy[ii,2]=sum(ACMx[,i+4][ACMx[,1]==32 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==32 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,3]=credits(sortdummy[,2])
                #agents get points for decreased etp at col. 3
                for(ii in 1:9) sortdummy[ii,4]=sum(ACMx[,i+4][ACMx[,1]==38 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==38 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,5]=credits(sortdummy[,4])
                #agents get credits for longest period below mean at col. 5
                for(ii in 1:9) sortdummy[ii,6]=sum(ACMx[,i+4][ACMx[,1]==37 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==37 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,7]=(-1)*credits(sortdummy[,6])
                #agents get credits for shortest period above mean at col. 7
                for(ii in 1:9){
                ad<-abs(ACMx[,i+4][ACMx[,1]==32 & ACMx[,2]==ii]/ACMx[,i+4][ACMx[,1]==31 & ACMx[,2]==ii]) #dev/abs(dev)
                ad[ad>1]=NA
                sortdummy[ii,8]=sum(ad,na.rm=T)/length(ad[!is.na(ad)])
                }
                #agents get credits for least fluctuation in terms of dev/abs(dev)=1
                sortdummy[,10]=apply(sortdummy[,c(3,5,7,9)],1,sum)
                
                agentrank[28:36,i]=sortdummy[,10]
                
                #THETA
                sortdummy<-matrix(0,9,10)
                sortdummy[,1]<-c(1:9)
                for(ii in 1:9) sortdummy[ii,2]=sum(ACMx[,i+4][ACMx[,1]==42 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==42 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,3]=(-1) * credits(sortdummy[,2])
                #agents get points for increased theta at col. 3
                for(ii in 1:9) sortdummy[ii,4]=sum(ACMx[,i+4][ACMx[,1]==47 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==47 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,5]=credits(sortdummy[,4])
                #agents get credits for longest period above mean at col. 5
                for(ii in 1:9) sortdummy[ii,6]=sum(ACMx[,i+4][ACMx[,1]==48 & ACMx[,2]==ii],na.rm=T)/length(ACMx[,i+4][ACMx[,1]==48 & ACMx[,2]==ii & !is.na(ACMx[,i+4])])
                sortdummy[,7]=(-1)*credits(sortdummy[,6])
                #agents get credits for shortest period below mean at col. 7
                for(ii in 1:9){
                ad<-abs(ACMx[,i+4][ACMx[,1]==42 & ACMx[,2]==ii]/ACMx[,i+4][ACMx[,1]==41 & ACMx[,2]==ii]) #dev/abs(dev)
                ad[ad>1]=NA
                sortdummy[ii,8]=sum(ad,na.rm=T)/length(ad[!is.na(ad)])
                }
                #agents get credits for least fluctuation in terms of dev/abs(dev)=1
                sortdummy[,10]=apply(sortdummy[,c(3,5,7,9)],1,sum)
                
                agentrank[37:45,i]=sortdummy[,10]
}

sortdummy3<-matrix(0,9,2)
sortdummy3[,1]<-c(1:9)

#rank agents for discharge behavior of whole catchment:
sortdummy2<-matrix(0,9,2)
sortdummy2[,1]<-c(1:9)
sortdummy2[,2]<-agentrank[1:9,64]
sortdummy3[,2]<-order(sortdummy2[,2])
wholedis_rank<-order(sortdummy3[,2])

#rank agents for general discharge behavior:
sortdummy2<-matrix(0,9,2)
sortdummy2[,1]<-c(1:9)
sortdummy2[,2]<-apply(agentrank[1:9,1:64],1,sum)
sortdummy3[,2]<-order(sortdummy2[,2])
generaldis_rank<-order(sortdummy3[,2])

#rank agents for overland flow behavior:
sortdummy2<-matrix(0,9,2)
sortdummy2[,1]<-c(1:9)
sortdummy2[,2]<-apply(agentrank[19:27,1:64],1,sum)
sortdummy3[,2]<-order(sortdummy2[,2])
overland_rank<-order(sortdummy3[,2])

#rank agents for general etp behavior:
sortdummy2<-matrix(0,9,2)
sortdummy2[,1]<-c(1:9)
sortdummy2[,2]<-apply(agentrank[28:36,1:64],1,sum)
sortdummy3[,2]<-order(sortdummy2[,2])
etp_rank<-order(sortdummy3[,2])

#rank agents for general theta behavior:
sortdummy2<-matrix(0,9,2)
sortdummy2[,1]<-c(1:9)
sortdummy2[,2]<-apply(agentrank[37:45,1:64],1,sum)
sortdummy3[,2]<-order(sortdummy2[,2])
theta_rank<-order(sortdummy3[,2])


#summary
rankdummy<-matrix(0,9,7)
rankdummy[,1]=wholedis_rank
rankdummy[,2]=generaldis_rank
rankdummy[,3]=overland_rank
rankdummy[,4]=etp_rank
rankdummy[,5]=theta_rank
rankdummy[,6]=apply(rankdummy[,1:5],1,sum)
rankdummy[,7]=c(1:9)

rankdummy[,7][order(rankdummy[,6])]

##############################################################################




#automated comparison of the whole matrix for all subbasins with credit-system
#   --> agent description
#   --> influence of agent
                                               

agentbase<-matrix(0,9,50)

for(i in 1:50) {
                corpus<-subset(ACMx[,2:68],ACMx[,1]==i)
                years<-unique(corpus[,3])
                weathers<-unique(corpus[,2])
                agentbasey<-matrix(0,9,length(years))
                for(iy in years) {
                                    agentbasew<-matrix(0,9,length(weathers))
                                    for(iw in weathers) {
                                    
                                    corpus2<-subset(corpus[,4:67],corpus[,3]==iy & corpus[,2]==iw)
                                    corpus2<-corpus2[1:9,]
                                    creditbase<-matrix(0,9,64)
                                    creditbase=apply(corpus2,1,credits)
                                    
                                    agentbasew[,c(1:length(weathers))[weathers==iw]]=apply(creditbase,2,function(x) sum(x,na.rm=T))
                                    
                                    }
                                    agentbasey[,c(1:length(years))[years==iy]]=apply(agentbasew,1,function(x) sum(x,na.rm=T))
                }
                agentbase[,i]=apply(agentbasey,1,function(x) sum(x,na.rm=T))
          }

agentbase

#interpretation
agentbase_inter<-matrix(0,9,5)
#discharge: fewer discharge, long period below mean, short above, dev/abs(dev)=1
credits(agentbase[,2]/agentbase[,1])

goutfile='agentindicees.ps'
postscript(goutfile,width=8,height=10,horizontal=FALSE,paper='a4')
 par(mfrow=c(4,1))
 for(i in 1:25) plot(agentbase[,i],1:9,xlab=i)
 for(i in 26:50) plot(agentbase[,i],1:9,xlab=i)
dev.off()




################################
# FURTHER PERFORMANCE ANALYSIS #
################################
doutfile<-'./result.dat'
 for(agent in 1:9) {
  for(weather in 1:18) {
    wasastat(paste('./wasa',agent,abc[weather],'/',sep=''),agent,weather,doutfile)
    print(paste('Done run for Agent',agent,'and Weather',abc[weather],'.'))
    }
   } 
 print('Thats it. Were through. Go and check your output file ./result.dat and the EPS files within the specific folders')
 print('Keep in mind, that theta still was not considered in this calculation.')
 
 print('Going for similarity analysis now.')
 



#######################
# likeliness analysis #
#######################


dfile='xxl.dat'
gfile='out.ps'

###################
#get data file
XXL<-read.table(dfile,header=F,sep='\t')
XXL<-as.data.frame(XXL)

postscript(gfile,width=7,height=10,horizontal=FALSE,paper='a4')
###################
#preparation: zeros and errors set to NA (in harvest results)
summary(XXL[,31:43])
XXL[,31:43][XXL[,31:43]==0]=NA
XXL[,31:43]=XXL[,31:43]/10000 #conversion m2 into ha to fit unit (kg)
summary(XXL[,31:43])

summary(XXL[,44:56])
XXL[,44:56][XXL[,44:56]==0]=NA
summary(XXL[,44:56])

summary(XXL[,57:69])
XXL[,57:69][XXL[,57:69]==0]=NA
XXL[,57:69][XXL[,57:69]>2500]=NA
summary(XXL[,57:69])

summary(XXL[,70:82])
XXL[,70:82][XXL[,70:82]==0]=NA
summary(XXL[,70:82])

#plot results
par(mfrow=c(5,1))
boxplot(XXL[,31:43],main='harvest of specific crop in the catchment each simulated year',ylab='kg/year',xlab='crop',notch=T)
boxplot(XXL[,44:56],main='cropped area of specific crop in the catchment each simulated year',ylab='m2 cropped',xlab='crop',notch=T)
boxplot(XXL[,57:69],main='inputs for specific crop in the catchment each simulated year',ylab='Rs/ha',xlab='crop',notch=T)
boxplot(XXL[,70:82],main='gains for specific crop in the catchment each simulated year',ylab='Rs/ha',xlab='crop',notch=T)
#profit
boxplot(XXL[,70:82]-XXL[,57:69],main='profits for specific crop in the catchment each simulated year',ylab='Rs/ha',xlab='crop',notch=T)


#####################
#overview about realizations

#harvest per crop under certain agents
par(mfrow=c(5,2))
boxplot(XXL[,31:43],main='harvest of specific crop',sub='yearly data of all simulations',xlab='crop',ylab='kg',notch=T)
for(ii in 1:9) {
			boxplot(subset(XXL[,31:43],XXL[,1]==ii),ylim=c(0,50000),sub=(paste('harvest at agent ',ii)),ylab='kg',notch=T)
				}

#profit per crop under certain agents
par(mfrow=c(5,2))
boxplot(XXL[,70:82]-XXL[,57:69],main='profit of specific crop',sub='yearly data of all simulations',xlab='crop',ylab='kg',notch=T)
for(ii in 1:9) {
			boxplot(subset(XXL[,70:82]-XXL[,57:69],XXL[,1]==ii),sub=(paste('profit at agent ',ii)),ylab='kg',notch=T)
				}

par(mfrow=c(5,2))
abc<-c('a','b','c','d','e','f','g','h','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z')
weathers<-unique(XXL[,2])
boxplot(XXL[,31:43],main='harvest of specific crop',sub='yearly data of all simulations',xlab='crop',ylab='kg',notch=T)
for(ii in 1:length(weathers)) {
			boxplot(subset(XXL[,31:43],XXL[,2]==weathers[ii]),ylim=c(0,50000),sub=(paste('harvest at weather ',abc[ii])),ylab='kg',notch=T)
				}

###################
#compare functions: sim -> simple vector comparison, problems with zeros
#					vec -> comparison through angle defined by the cropping vector, problems in interpretations

compare_sim<-function(XX,YY) { #compare a one years cropping vector to all the matrix of the same length
		ZZ<-matrix(ncol=ncol(YY),nrow=2,data=1)
		ZZ[1,]<-as.numeric(XX)
		AA<-numeric(nrow(YY))
 		minmaxnan<-function(x) {
					 x1<-min(abs(x))/max(abs(x))
					 if(is.null(x1) | max(is.na(x1))==1 | min(abs(x))==0) x1=0 
					 x1
					  }
		for(i in 1:nrow(YY)) {
			ZZ[2,]<-as.numeric(YY[i,])
			AA[i]<-sum(apply(ZZ,2,minmaxnan)/max(length(ZZ[1,][abs(ZZ[1,])>0]),length(ZZ[2,][abs(ZZ[2,])>0])))
			if(is.na(AA[i])) AA[i]=0
                          }
		AA
		}
		
compare_vec<-function(XX,YY) { #compare vector to all the matrix through angle calculation
		XX<-as.numeric(XX)
		YY<-as.data.frame(YY)
		AA<-numeric(nrow(YY))
		vec_angel<-function(x) {
					acos((XX%*%x)/(sqrt(XX%*%XX)*sqrt(x%*%x)))
					}
		AA<-apply(YY,1,vec_angel)
		AA
		}
				
#likeliness within realizations of same agent		
like_inagent_k<-matrix(ncol=9, nrow=nrow(subset(XXL[,31:43],XXL[,4]==1 & XXL[,1]==1)))
like_inagent_r<-matrix(ncol=9, nrow=nrow(subset(XXL[,31:43],XXL[,4]==2 & XXL[,1]==1)))
for(j in 1:9) {
	kharif<-as.data.frame(subset(XXL[,31:43],XXL[,4]==1 & XXL[,1]==j))
	print(paste('compare kharif of agent ',j))
	ka<-numeric(length(kharif))
  ka<-apply(apply(kharif,1,function(x) compare_sim(x,kharif)),1,median)
	like_inagent_k[,j]<-ka[1:312]
  
  rabi<-as.data.frame(subset(XXL[,31:43],XXL[,4]==2 & XXL[,1]==j))
	ra<-numeric(length(rabi))
	print(paste('compare rabi of agent ',j))
  ra<-apply(apply(rabi,1,function(x) compare_sim(x,rabi)),1,median)
	like_inagent_r[,j]<-ra[1:312]
  }
	
par(mfrow=c(2,1))
boxplot(like_inagent_k[,1],like_inagent_k[,2],like_inagent_k[,3],like_inagent_k[,4],like_inagent_k[,5],like_inagent_k[,6],like_inagent_k[,7],like_inagent_k[,8],like_inagent_k[,9],main='Likeliness among croppings of the same agent in kharif',xlab='Agent',ylab='likeliness',notch=T)
boxplot(like_inagent_r[,1],like_inagent_r[,2],like_inagent_r[,3],like_inagent_r[,4],like_inagent_r[,5],like_inagent_r[,6],like_inagent_r[,7],like_inagent_r[,8],like_inagent_r[,9],main='Likeliness among croppings of the same agent in rabi',xlab='Agent',ylab='likeliness',notch=T)

#here other likeliness querries could be applied...


####################
#success of agent's constraint?

#target parameters: harvested amout of specific crop,
#					gains from cropping,
#					lost investments (?),
gains_k<-matrix(NA,312,9)
gains_r<-gains_k
for(ii in 1:9) {
				#kharif
				harvest1<-subset(XXL[,31:43],XXL[,4]==1 & XXL[,1]==ii)
				harvest2<-subset(XXL[,44:56],XXL[,4]==1 & XXL[,1]==ii)
        profit<-subset(XXL[,70:82],XXL[,4]==1 & XXL[,1]==ii) - subset(XXL[,57:69],XXL[,4]==1 & XXL[,1]==ii) 
				print(' ')
				print('*****************************************')
				print(paste('Summary of cropped areas in kharif at agent ',ii))
				summary(harvest1)
				print(' ')
				print(paste('Summary of harvests per crop in kharif at agent ',ii))
				summary(harvest2)
				
        gains_k[,ii]<-as.numeric(apply((profit/100) * (harvest1*(harvest2/10000)),1,function(x) sum(x,na.rm=T)))[1:312]
				
				#rabi
				harvest1<-subset(XXL[,31:43],XXL[,4]==2 & XXL[,1]==ii)
				harvest2<-subset(XXL[,44:56],XXL[,4]==2 & XXL[,1]==ii)
				profit<-subset(XXL[,70:82],XXL[,4]==2 & XXL[,1]==ii) - subset(XXL[,57:69],XXL[,4]==2 & XXL[,1]==ii) 
        print(' ')
				print('* * * * * * * * * * * * * * * * * * * * *')
				print(paste('Summary of cropped area in rabi at agent ',ii))
				summary(harvest1)
				print(' ')
				print(paste('Summary of harvests per crop in kharif at agent ',ii))
				summary(harvest2)
        
        gains_r[,ii]<-as.numeric(apply((profit/100) * (harvest1*(harvest2/10000)),1,function(x) sum(x,na.rm=T)))[1:312]
				}

par(mfrow=c(2,1))
boxplot(gains_k[,1],gains_k[,2],gains_k[,3],gains_k[,5],gains_k[,5],gains_k[,6],gains_k[,7],gains_k[,8],gains_k[,9],main='profits from kharif harvest depending on agent',xlab='agent',ylab='Rs/yr',notch=T)
boxplot(gains_r[,1],gains_r[,2],gains_r[,3],gains_r[,5],gains_r[,5],gains_r[,6],gains_r[,7],gains_r[,8],gains_r[,9],main='profits from rabi harvest depending on agent',xlab='agent',ylab='Rs/yr',notch=T)


####################
#environmental impact

#target parameters: precipitation/discharge/theta-relationship (what strategy keeps most water in catchment?)
#					overall discharge/overland flow (what strategy has lowest peaks?)
Mdis<-matrix(NA,624,9)
MTdis<-Mdis
Vdis<-Mdis
VTdis<-Mdis
MXdis<-Mdis
Sdis<-Mdis
Xdis<-Mdis
				
Msub<-Mdis
Vsub<-Mdis
MXsub<-Mdis
Ssub<-Mdis
				
Mover<-Mdis
Vover<-Mdis
MXover<-Mdis
Sover<-Mdis
				
Metp<-Mdis
Vetp<-Mdis
MXetp<-Mdis
MNetp<-Mdis

XXL[,27][XXL[,27]>1000]=0
XXL[,28][XXL[,28]>600]=0
XXL[,29][XXL[,29]>1000]=0
XXL[,30][XXL[,30]>1000]=0

for(ii in 1:9) {
				prec<-subset(XXL[,5:11],XXL[,1]==ii)
				disc<-subset(XXL[,12:18],XXL[,1]==ii)
				subf<-subset(XXL[,19:22],XXL[,1]==ii)
				over<-subset(XXL[,23:26],XXL[,1]==ii)
				etp<-subset(XXL[,27:30],XXL[,1]==ii)
				
				par(mfrow=c(5,1))
				boxplot(prec,ylim=c(0,3000),main=paste('Environmental parameters for agent ',ii,' simulations'), sub='Precipitation Characteristics',notch=T)
				boxplot(disc,ylim=c(0,2000),sub='Discharge Characteristics',notch=T)
				boxplot(subf,sub='Subsurface Run-off Characteristics',notch=T)
				boxplot(over,sub='Overland Flow Characteristics',notch=T)
				boxplot(etp,ylim=c(0,7),sub='Evapotranspiration Characteristics',notch=T)
				
				print(' ')
				print('*****************************************')
				print(paste('Summary of precipitation at agent ',ii))
				summary(prec)
				print(summary(prec))
        print(' ')
				print(paste('Summary of discharge at agent ',ii))
				summary(disc)
				print(summary(disc))
				print(' ')
				print(paste('Summary of subsurface flow at agent ',ii))
				summary(subf)
				print(summary(subf))
				print(' ')
				print(paste('Summary of overland flow at agent ',ii))
				summary(over)
				print(summary(over))
				print(' ')
				print(paste('Summary of evapotranspiration at agent ',ii))
				summary(etp)
				print(summary(etp))
				print(' ')
				
				Mdis[,ii]<-disc[,1][1:624]
				MTdis[,ii]<-disc[,2][1:624]
				Vdis[,ii]<-disc[,3][1:624]
				VTdis[,ii]<-disc[,4][1:624]
				MXdis[,ii]<-disc[,5][1:624]
				Sdis[,ii]<-disc[,6][1:624]
				Xdis[,ii]<-disc[,7][1:624]
				
				Msub[,ii]<-subf[,1][1:624]
				Vsub[,ii]<-subf[,2][1:624]
				MXsub[,ii]<-subf[,3][1:624]
				Ssub[,ii]<-subf[,4][1:624]
				
				Mover[,ii]<-over[,1][1:624]
				Vover[,ii]<-over[,2][1:624]
				MXover[,ii]<-over[,3][1:624]
				Sover[,ii]<-over[,4][1:624]
				
				Metp[,ii]<-etp[,1][1:624]
				Vetp[,ii]<-etp[,2][1:624]
				MXetp[,ii]<-etp[,3][1:624]
				MNetp[,ii]<-etp[,4][1:624]
				
				}

par(mfrow=c(4,2))
boxplot(prec[,1],main='Environmental parameters for agents - PRECIPITATION', sub='Mean Precipitation',xlab='agent',ylab='mm/d',notch=T)				
boxplot(prec[,2], sub='Mean Precipitation without zeros',xlab='agent',ylab='mm/d',notch=T)				
boxplot(prec[,3], sub='Precipitation Variance',ylab='mm/d',notch=T)				
boxplot(prec[,4], sub='Precipitation Variance without zeros',ylab='mm/d',notch=T)				
boxplot(prec[,5], sub='Maximum Precipitation',ylab='mm/d',notch=T)				
boxplot(prec[,6], sub='Annual Sum of Precipitation',ylab='mm',notch=T)
boxplot(prec[,7], sub='Precipitation events',ylab='days',notch=T)	

par(mfrow=c(4,1))
boxplot(Mdis[,1],Mdis[,2],Mdis[,3],Mdis[,4],Mdis[,5],Mdis[,6],Mdis[,7],Mdis[,8],Mdis[,9],main='Environmental parameters for agents - DISCHARGE', sub='Mean Discharge',xlab='agent',ylab='m3/s',notch=T)				
boxplot(MTdis[,1],MTdis[,2],MTdis[,3],MTdis[,4],MTdis[,5],MTdis[,6],MTdis[,7],MTdis[,8],MTdis[,9], sub='Mean Discharge without zeros',xlab='agent',ylab='m3/s',notch=T)				
boxplot(Vdis[,1],Vdis[,2],Vdis[,3],Vdis[,4],Vdis[,5],Vdis[,6],Vdis[,7],Vdis[,8],Vdis[,9], sub='Discharge Variance',xlab='agent',ylab='m3/s',notch=T)				
boxplot(VTdis[,1],VTdis[,2],VTdis[,3],VTdis[,4],VTdis[,5],VTdis[,6],VTdis[,7],VTdis[,8],VTdis[,9], sub='Discharge Variance without zeros',xlab='agent',ylab='m3/s',notch=T)				
boxplot(MXdis[,1],MXdis[,2],MXdis[,3],MXdis[,4],MXdis[,5],MXdis[,6],MXdis[,7],MXdis[,8],MXdis[,9], sub='Maximum Discharge',xlab='agent',ylab='m3/s',notch=T)				
boxplot(Sdis[,1],Sdis[,2],Sdis[,3],Sdis[,4],Sdis[,5],Sdis[,6],Sdis[,7],Sdis[,8],Sdis[,9], sub='Sum of Discharge',xlab='agent',ylab='m3',notch=T)
boxplot(Xdis[,1],Xdis[,2],Xdis[,3],Xdis[,4],Xdis[,5],Xdis[,6],Xdis[,7],Xdis[,8],Xdis[,9], sub='Discharge events',xlab='agent',ylab='days',notch=T)	

par(mfrow=c(4,1))
boxplot(Msub[,1],Msub[,2],Msub[,3],Msub[,4],Msub[,5],Msub[,6],Msub[,7],Msub[,8],Msub[,9],main='Environmental parameters for agents - SUBSURFACE FLOW', sub='Mean Subsurface Flow',xlab='agent',ylab='m3/s',notch=T)				
boxplot(Vsub[,1],Vsub[,2],Vsub[,3],Vsub[,4],Vsub[,5],Vsub[,6],Vsub[,7],Vsub[,8],Vsub[,9], sub='Subsurface Flow Variance',xlab='agent',ylab='m3/s',notch=T)				
boxplot(MXsub[,1],MXsub[,2],MXsub[,3],MXsub[,4],MXsub[,5],MXsub[,6],MXsub[,7],MXsub[,8],MXsub[,9], sub='Subsurface Flow Maximum',xlab='agent',ylab='m3/s',notch=T)
boxplot(Ssub[,1],Ssub[,2],Ssub[,3],Ssub[,4],Ssub[,5],Ssub[,6],Ssub[,7],Ssub[,8],Ssub[,9], sub='Annual Sum of Subsurface Flow',xlab='agent',ylab='m3/s',notch=T)

par(mfrow=c(4,1))
boxplot(Mover[,1],Mover[,2],Mover[,3],Mover[,4],Mover[,5],Mover[,6],Mover[,7],Mover[,8],Mover[,9],main='Environmental parameters for agents - OVERLAND FLOW', sub='Mean Overland Flow',xlab='agent',ylab='m3/s',notch=T)				
boxplot(Vover[,1],Vover[,2],Vover[,3],Vover[,4],Vover[,5],Vover[,6],Vover[,7],Vover[,8],Vover[,9], sub='Overland Flow Variance',xlab='agent',ylab='m3/s',notch=T)				
boxplot(MXover[,1],MXover[,2],MXover[,3],MXover[,4],MXover[,5],MXover[,6],MXover[,7],MXover[,8],MXover[,9], sub='Overland Flow Maximum',xlab='agent',ylab='m3/s',notch=T)
boxplot(Sover[,1],Sover[,2],Sover[,3],Sover[,4],Sover[,5],Sover[,6],Sover[,7],Sover[,8],Sover[,9], sub='Annual Sum of Overland Flow',xlab='agent',ylab='m3/s',notch=T)

par(mfrow=c(4,1))
boxplot(Metp[,1],Metp[,2],Metp[,3],Metp[,4],Metp[,5],Metp[,6],Metp[,7],Metp[,8],Metp[,9],main='Environmental parameters for agents - EVAPOTRANSPIRATION', sub='Mean ETP',xlab='agent',ylab='mm/d',notch=T)				
boxplot(Vetp[,1],Vetp[,2],Vetp[,3],Vetp[,4],Vetp[,5],Vetp[,6],Vetp[,7],Vetp[,8],Vetp[,9], sub='ETP Variance',xlab='agent',ylab='mm/d',notch=T)				
boxplot(MXetp[,1],MXetp[,2],MXetp[,3],MXetp[,4],MXetp[,5],MXetp[,6],MXetp[,7],MXetp[,8],MXetp[,9], sub='ETP Maximum',xlab='agent',ylab='mm/d',notch=T)
boxplot(MNetp[,1],MNetp[,2],MNetp[,3],MNetp[,4],MNetp[,5],MNetp[,6],MNetp[,7],MNetp[,8],MNetp[,9], sub='ETP Minimum',xlab='agent',ylab='mm/d',notch=T)


####################
#3d plots harvest-year-weather
#         discharge-year-weather				
#use package scatterplot3d on unix		




####################
#is the model able to simulate differences of land use and its impact on the water household?
#is this somehow plausible?


####################
#XXL-Matrix:
#XXL[idx,1]=AGENT
#XXL[idx,2]=WEATHER
#XXL[idx,3]=years[i]
#XXL[idx,4]=c(1,2) #season

#XXL[idx,5]=prec_m
#XXL[idx,6]=prec_mt
#XXL[idx,7]=prec_v
#XXL[idx,8]=prec_vt
#XXL[idx,9]=prec_mx
#XXL[idx,10]=prec_s
#XXL[idx,11]=prec_x

#XXL[idx,12]=dis_m
#XXL[idx,13]=dis_mt
#XXL[idx,14]=dis_v
#XXL[idx,15]=dis_vt
#XXL[idx,16]=dis_mx
#XXL[idx,17]=dis_s
#XXL[idx,18]=dis_x

#XXL[idx,19]=sub_m
#XXL[idx,20]=sub_v
#XXL[idx,21]=sub_mx
#XXL[idx,22]=sub_s

#XXL[idx,23]=over_m
#XXL[idx,24]=over_v
#XXL[idx,25]=over_mx
#XXL[idx,26]=over_s

#XXL[idx,27]=etp_m
#XXL[idx,28]=etp_v
#XXL[idx,29]=etp_mx
#XXL[idx,30]=etp_mn

#crop values now
#XXL[idx,31:43]=harv_rk	#area cropped
#XXL[idx,44:56]=harv_ak	#harvested amount of crops
#XXL[idx,57:69]=harv_ik	#inputs			
#XXL[idx,70:82]=harv_gk	#gains

dev.off()