#wasa simulations result interpreter
#this script aims to prepare an analysis of the XXL.dat data from r_wasaout

#(cc) conrad jackisch, feb. 2007, inst. for geoecology, university potsdam
#	  jackisch@uni-potsdam.de

#version 0.1


dfile='e:/data/conrad/conrad_simulations/xxl.dat'
gfile='e:/data/conrad/conrad_simulations/out.ps'

###################
#get data file
XXL<-read.table(dfile,header=F,sep='\t')
XXL<-as.data.frame(XXL)

postscript(gfile,width=7,height=10,horizontal=FALSE,paper='a4')
###################
#preparation: zeros and errors set to NA (in harvest results)
summary(XXL[,31:43])
XXL[,31:43][XXL[,31:43]==0]=NA
XXL[,31:43]=XXL[,31:43]/10000 #conversion m2 into ha to fit unit (kg)
summary(XXL[,31:43])

summary(XXL[,44:56])
XXL[,44:56][XXL[,44:56]==0]=NA
summary(XXL[,44:56])

summary(XXL[,57:69])
XXL[,57:69][XXL[,57:69]==0]=NA
XXL[,57:69][XXL[,57:69]>2500]=NA
summary(XXL[,57:69])

summary(XXL[,70:82])
XXL[,70:82][XXL[,70:82]==0]=NA
summary(XXL[,70:82])

#plot results
par(mfrow=c(5,1))
boxplot(XXL[,31:43],main='harvest of specific crop in the catchment each simulated year',ylab='kg',notch=T)
boxplot(XXL[,44:56],main='cropped area of specific crop in the catchment each simulated year',ylab='m2',notch=T)
boxplot(XXL[,57:69],main='inputs for specific crop in the catchment each simulated year',ylab='Rs/ha',notch=T)
boxplot(XXL[,70:82],main='gains for specific crop in the catchment each simulated year',ylab='Rs/ha',notch=T)
#profit
boxplot(XXL[,70:82]-XXL[,57:69],main='profits for specific crop in the catchment each simulated year',ylab='Rs/ha',notch=T)


#####################
#overview about realizations

#harvest per crop under certain agents
par(mfrow=c(5,2))
boxplot(XXL[,31:43],main='harvest of specific crop',sub='yearly data of all simulations',xlab='crop',ylab='kg',notch=T)
for(ii in 1:9) {
			boxplot(subset(XXL[,31:43],XXL[,1]==ii),ylim=c(0,50000),sub=(paste('harvest at agent ',ii)),ylab='kg',notch=T)
				}

par(mfrow=c(5,2))
abc<-c('a','b','c','d','e','f','g','h','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z')
weathers<-unique(XXL[,2])
boxplot(XXL[,31:43],main='harvest of specific crop',sub='yearly data of all simulations',xlab='crop',ylab='kg',notch=T)
for(ii in 1:length(weathers)) {
			boxplot(subset(XXL[,31:43],XXL[,2]==weathers[ii]),ylim=c(0,50000),sub=(paste('harvest at weather ',abc[ii])),ylab='kg',notch=T)
				}

###################
#compare functions: sim -> simple vector comparison, problems with zeros
#					vec -> comparison through angle defined by the cropping vector, problems in interpretations

compare_sim<-function(XX,YY) { #compare a one years cropping vector to all the matrix of the same length
		ZZ<-matrix(ncol=ncol(YY),nrow=2,data=1)
		ZZ[1,]<-as.numeric(XX)
		AA<-numeric(nrow(YY))
 		minmaxnan<-function(x) {
					 x1<-min(abs(x))/max(abs(x))
					 if(is.null(x1) | max(is.na(x1))==1 | min(abs(x))==0) x1=0 
					 x1
					  }
		for(i in 1:nrow(YY)) {
			ZZ[2,]<-as.numeric(YY[i,])
			AA[i]<-sum(apply(ZZ,2,minmaxnan)/max(length(ZZ[1,][abs(ZZ[1,])>0]),length(ZZ[2,][abs(ZZ[2,])>0])))
			if(is.na(AA[i])) AA[i]=0
                          }
		AA
		}
		
compare_vec<-function(XX,YY) { #compare vector to all the matrix through angle calculation
		XX<-as.numeric(XX)
		YY<-as.data.frame(YY)
		AA<-numeric(nrow(YY))
		vec_angel<-function(x) {
					acos((XX%*%x)/(sqrt(XX%*%XX)*sqrt(x%*%x)))
					}
		AA<-apply(YY,1,vec_angel)
		AA
		}
				
#likeliness within realizations of same agent		
like_inagent_k<-matrix(ncol=9, nrow=nrow(subset(XXL[,31:43],XXL[,4]==1 & XXL[,1]==1)))
like_inagent_r<-matrix(ncol=9, nrow=nrow(subset(XXL[,31:43],XXL[,4]==2 & XXL[,1]==1)))
for(j in 1:9) {
	kharif<-as.data.frame(subset(XXL[,31:43],XXL[,4]==1 & XXL[,1]==j))
	print(paste('compare kharif of agent ',j))
	ka<-numeric(length(kharif))
  ka<-apply(apply(kharif,1,function(x) compare_sim(x,kharif)),1,median)
	like_inagent_k[,j]<-ka[1:312]
  
  rabi<-as.data.frame(subset(XXL[,31:43],XXL[,4]==2 & XXL[,1]==j))
	ra<-numeric(length(rabi))
	print(paste('compare rabi of agent ',j))
  ra<-apply(apply(rabi,1,function(x) compare_sim(x,rabi)),1,median)
	like_inagent_r[,j]<-ra[1:312]
  }
	
par(mfrow=c(2,1))
boxplot(like_inagent_k[,1],like_inagent_k[,2],like_inagent_k[,3],like_inagent_k[,4],like_inagent_k[,5],like_inagent_k[,6],like_inagent_k[,7],like_inagent_k[,8],like_inagent_k[,9],main='Likeliness among croppings of the same agent in kharif',xlab='Agent',ylab='likeliness',notch=T)
boxplot(like_inagent_r[,1],like_inagent_r[,2],like_inagent_r[,3],like_inagent_r[,4],like_inagent_r[,5],like_inagent_r[,6],like_inagent_r[,7],like_inagent_r[,8],like_inagent_r[,9],main='Likeliness among croppings of the same agent in rabi',xlab='Agent',ylab='likeliness',notch=T)

#here other likeliness querries could be applied...


####################
#success of agent's constraint?

#target parameters: harvested amout of specific crop,
#					gains from cropping,
#					lost investments (?),
gains_k<-matrix(NA,312,9)
gains_r<-gains_k
for(ii in 1:9) {
				#kharif
				harvest1<-subset(XXL[,31:43],XXL[,4]==1 & XXL[,1]==ii)
				harvest2<-subset(XXL[,44:56],XXL[,4]==1 & XXL[,1]==ii)
        profit<-subset(XXL[,70:82],XXL[,4]==1 & XXL[,1]==ii) - subset(XXL[,57:69],XXL[,4]==1 & XXL[,1]==ii) 
				print(' ')
				print('*****************************************')
				print(paste('Summary of cropped areas in kharif at agent ',ii))
				summary(harvest1)
				print(' ')
				print(paste('Summary of harvests per crop in kharif at agent ',ii))
				summary(harvest2)
				
        gains_k[,ii]<-as.numeric(apply((profit/100) * (harvest1*(harvest2/10000)),1,function(x) sum(x,na.rm=T)))[1:312]
				
				#rabi
				harvest1<-subset(XXL[,31:43],XXL[,4]==2 & XXL[,1]==ii)
				harvest2<-subset(XXL[,44:56],XXL[,4]==2 & XXL[,1]==ii)
				profit<-subset(XXL[,70:82],XXL[,4]==2 & XXL[,1]==ii) - subset(XXL[,57:69],XXL[,4]==2 & XXL[,1]==ii) 
        print(' ')
				print('* * * * * * * * * * * * * * * * * * * * *')
				print(paste('Summary of cropped area in rabi at agent ',ii))
				summary(harvest1)
				print(' ')
				print(paste('Summary of harvests per crop in kharif at agent ',ii))
				summary(harvest2)
        
        gains_r[,ii]<-as.numeric(apply((profit/100) * (harvest1*(harvest2/10000)),1,function(x) sum(x,na.rm=T)))[1:312]
				}

par(mfrow=c(2,1))
boxplot(gains_k[,1],gains_k[,2],gains_k[,3],gains_k[,5],gains_k[,5],gains_k[,6],gains_k[,7],gains_k[,8],gains_k[,9],main='profits from kharif harvest depending on agent',xlab='agent',ylab='Rs/yr',notch=T)
boxplot(gains_r[,1],gains_r[,2],gains_r[,3],gains_r[,5],gains_r[,5],gains_r[,6],gains_r[,7],gains_r[,8],gains_r[,9],main='profits from rabi harvest depending on agent',xlab='agent',ylab='Rs/yr',notch=T)


####################
#environmental impact

#target parameters: precipitation/discharge/theta-relationship (what strategy keeps most water in catchment?)
#					overall discharge/overland flow (what strategy has lowest peaks?)
Mdis<-matrix(NA,624,9)
MTdis<-Mdis
Vdis<-Mdis
VTdis<-Mdis
MXdis<-Mdis
Sdis<-Mdis
Xdis<-Mdis
				
Msub<-Mdis
Vsub<-Mdis
MXsub<-Mdis
Ssub<-Mdis
				
Mover<-Mdis
Vover<-Mdis
MXover<-Mdis
Sover<-Mdis
				
Metp<-Mdis
Vetp<-Mdis
MXetp<-Mdis
MNetp<-Mdis

XXL[,27][XXL[,27]>1000]=0
XXL[,28][XXL[,28]>600]=0
XXL[,29][XXL[,29]>1000]=0
XXL[,30][XXL[,30]>1000]=0

for(ii in 1:9) {
				prec<-subset(XXL[,5:11],XXL[,1]==ii)
				disc<-subset(XXL[,12:18],XXL[,1]==ii)
				subf<-subset(XXL[,19:22],XXL[,1]==ii)
				over<-subset(XXL[,23:26],XXL[,1]==ii)
				etp<-subset(XXL[,27:30],XXL[,1]==ii)
				
				par(mfrow=c(5,1))
				boxplot(prec,ylim=c(0,3000),main=paste('Environmental parameters for agent ',ii,' simulations'), sub='Precipitation Characteristics',notch=T)
				boxplot(disc,ylim=c(0,2000),sub='Discharge Characteristics',notch=T)
				boxplot(subf,sub='Subsurface Run-off Characteristics',notch=T)
				boxplot(over,sub='Overland Flow Characteristics',notch=T)
				boxplot(etp,ylim=c(0,7),sub='Evapotranspiration Characteristics',notch=T)
				
				print(' ')
				print('*****************************************')
				print(paste('Summary of precipitation at agent ',ii))
				summary(prec)
				print(summary(prec))
        print(' ')
				print(paste('Summary of discharge at agent ',ii))
				summary(disc)
				print(summary(disc))
				print(' ')
				print(paste('Summary of subsurface flow at agent ',ii))
				summary(subf)
				print(summary(subf))
				print(' ')
				print(paste('Summary of overland flow at agent ',ii))
				summary(over)
				print(summary(over))
				print(' ')
				print(paste('Summary of evapotranspiration at agent ',ii))
				summary(etp)
				print(summary(etp))
				print(' ')
				
				Mdis[,ii]<-disc[,1][1:624]
				MTdis[,ii]<-disc[,2][1:624]
				Vdis[,ii]<-disc[,3][1:624]
				VTdis[,ii]<-disc[,4][1:624]
				MXdis[,ii]<-disc[,5][1:624]
				Sdis[,ii]<-disc[,6][1:624]
				Xdis[,ii]<-disc[,7][1:624]
				
				Msub[,ii]<-subf[,1][1:624]
				Vsub[,ii]<-subf[,2][1:624]
				MXsub[,ii]<-subf[,3][1:624]
				Ssub[,ii]<-subf[,4][1:624]
				
				Mover[,ii]<-over[,1][1:624]
				Vover[,ii]<-over[,2][1:624]
				MXover[,ii]<-over[,3][1:624]
				Sover[,ii]<-over[,4][1:624]
				
				Metp[,ii]<-etp[,1][1:624]
				Vetp[,ii]<-etp[,2][1:624]
				MXetp[,ii]<-etp[,3][1:624]
				MNetp[,ii]<-etp[,4][1:624]
				
				}

par(mfrow=c(4,2))
boxplot(prec[,1],main='Environmental parameters for agents - PRECIPITATION', sub='Mean Precipitation',xlab='agent',ylab='mm/d',notch=T)				
boxplot(prec[,2], sub='Mean Precipitation without zeros',xlab='agent',ylab='mm/d',notch=T)				
boxplot(prec[,3], sub='Precipitation Variance',ylab='mm/d',notch=T)				
boxplot(prec[,4], sub='Precipitation Variance without zeros',ylab='mm/d',notch=T)				
boxplot(prec[,5], sub='Maximum Precipitation',ylab='mm/d',notch=T)				
boxplot(prec[,6], sub='Annual Sum of Precipitation',ylab='mm',notch=T)
boxplot(prec[,7], sub='Precipitation events',ylab='days',notch=T)	

par(mfrow=c(4,1))
boxplot(Mdis[,1],Mdis[,2],Mdis[,3],Mdis[,4],Mdis[,5],Mdis[,6],Mdis[,7],Mdis[,8],Mdis[,9],main='Environmental parameters for agents - DISCHARGE', sub='Mean Discharge',xlab='agent',ylab='m3/s',notch=T)				
boxplot(MTdis[,1],MTdis[,2],MTdis[,3],MTdis[,4],MTdis[,5],MTdis[,6],MTdis[,7],MTdis[,8],MTdis[,9], sub='Mean Discharge without zeros',xlab='agent',ylab='m3/s',notch=T)				
boxplot(Vdis[,1],Vdis[,2],Vdis[,3],Vdis[,4],Vdis[,5],Vdis[,6],Vdis[,7],Vdis[,8],Vdis[,9], sub='Discharge Variance',xlab='agent',ylab='m3/s',notch=T)				
boxplot(VTdis[,1],VTdis[,2],VTdis[,3],VTdis[,4],VTdis[,5],VTdis[,6],VTdis[,7],VTdis[,8],VTdis[,9], sub='Discharge Variance without zeros',xlab='agent',ylab='m3/s',notch=T)				
boxplot(MXdis[,1],MXdis[,2],MXdis[,3],MXdis[,4],MXdis[,5],MXdis[,6],MXdis[,7],MXdis[,8],MXdis[,9], sub='Maximum Discharge',xlab='agent',ylab='m3/s',notch=T)				
boxplot(Sdis[,1],Sdis[,2],Sdis[,3],Sdis[,4],Sdis[,5],Sdis[,6],Sdis[,7],Sdis[,8],Sdis[,9], sub='Sum of Discharge',xlab='agent',ylab='m3',notch=T)
boxplot(Xdis[,1],Xdis[,2],Xdis[,3],Xdis[,4],Xdis[,5],Xdis[,6],Xdis[,7],Xdis[,8],Xdis[,9], sub='Discharge events',xlab='agent',ylab='days',notch=T)	

par(mfrow=c(4,1))
boxplot(Msub[,1],Msub[,2],Msub[,3],Msub[,4],Msub[,5],Msub[,6],Msub[,7],Msub[,8],Msub[,9],main='Environmental parameters for agents - SUBSURFACE FLOW', sub='Mean Subsurface Flow',xlab='agent',ylab='m3/s',notch=T)				
boxplot(Vsub[,1],Vsub[,2],Vsub[,3],Vsub[,4],Vsub[,5],Vsub[,6],Vsub[,7],Vsub[,8],Vsub[,9], sub='Subsurface Flow Variance',xlab='agent',ylab='m3/s',notch=T)				
boxplot(MXsub[,1],MXsub[,2],MXsub[,3],MXsub[,4],MXsub[,5],MXsub[,6],MXsub[,7],MXsub[,8],MXsub[,9], sub='Subsurface Flow Maximum',xlab='agent',ylab='m3/s',notch=T)
boxplot(Ssub[,1],Ssub[,2],Ssub[,3],Ssub[,4],Ssub[,5],Ssub[,6],Ssub[,7],Ssub[,8],Ssub[,9], sub='Annual Sum of Subsurface Flow',xlab='agent',ylab='m3/s',notch=T)

par(mfrow=c(4,1))
boxplot(Mover[,1],Mover[,2],Mover[,3],Mover[,4],Mover[,5],Mover[,6],Mover[,7],Mover[,8],Mover[,9],main='Environmental parameters for agents - OVERLAND FLOW', sub='Mean Overland Flow',xlab='agent',ylab='m3/s',notch=T)				
boxplot(Vover[,1],Vover[,2],Vover[,3],Vover[,4],Vover[,5],Vover[,6],Vover[,7],Vover[,8],Vover[,9], sub='Overland Flow Variance',xlab='agent',ylab='m3/s',notch=T)				
boxplot(MXover[,1],MXover[,2],MXover[,3],MXover[,4],MXover[,5],MXover[,6],MXover[,7],MXover[,8],MXover[,9], sub='Overland Flow Maximum',xlab='agent',ylab='m3/s',notch=T)
boxplot(Sover[,1],Sover[,2],Sover[,3],Sover[,4],Sover[,5],Sover[,6],Sover[,7],Sover[,8],Sover[,9], sub='Annual Sum of Overland Flow',xlab='agent',ylab='m3/s',notch=T)

par(mfrow=c(4,1))
boxplot(Metp[,1],Metp[,2],Metp[,3],Metp[,4],Metp[,5],Metp[,6],Metp[,7],Metp[,8],Metp[,9],main='Environmental parameters for agents - EVAPOTRANSPIRATION', sub='Mean ETP',xlab='agent',ylab='mm/d',notch=T)				
boxplot(Vetp[,1],Vetp[,2],Vetp[,3],Vetp[,4],Vetp[,5],Vetp[,6],Vetp[,7],Vetp[,8],Vetp[,9], sub='ETP Variance',xlab='agent',ylab='mm/d',notch=T)				
boxplot(MXetp[,1],MXetp[,2],MXetp[,3],MXetp[,4],MXetp[,5],MXetp[,6],MXetp[,7],MXetp[,8],MXetp[,9], sub='ETP Maximum',xlab='agent',ylab='mm/d',notch=T)
boxplot(MNetp[,1],MNetp[,2],MNetp[,3],MNetp[,4],MNetp[,5],MNetp[,6],MNetp[,7],MNetp[,8],MNetp[,9], sub='ETP Minimum',xlab='agent',ylab='mm/d',notch=T)


####################
#3d plots harvest-year-weather
#         discharge-year-weather				
#see mac... scatterplot3d		




####################
#is the model able to simulate differences of land use and its impact on the water household?
#is this somehow plausible?


####################
#XXL-Matrix:
#XXL[idx,1]=AGENT
#XXL[idx,2]=WEATHER
#XXL[idx,3]=years[i]
#XXL[idx,4]=c(1,2) #season

#XXL[idx,5]=prec_m
#XXL[idx,6]=prec_mt
#XXL[idx,7]=prec_v
#XXL[idx,8]=prec_vt
#XXL[idx,9]=prec_mx
#XXL[idx,10]=prec_s
#XXL[idx,11]=prec_x

#XXL[idx,12]=dis_m
#XXL[idx,13]=dis_mt
#XXL[idx,14]=dis_v
#XXL[idx,15]=dis_vt
#XXL[idx,16]=dis_mx
#XXL[idx,17]=dis_s
#XXL[idx,18]=dis_x

#XXL[idx,19]=sub_m
#XXL[idx,20]=sub_v
#XXL[idx,21]=sub_mx
#XXL[idx,22]=sub_s

#XXL[idx,23]=over_m
#XXL[idx,24]=over_v
#XXL[idx,25]=over_mx
#XXL[idx,26]=over_s

#XXL[idx,27]=etp_m
#XXL[idx,28]=etp_v
#XXL[idx,29]=etp_mx
#XXL[idx,30]=etp_mn

#crop values now
#XXL[idx,31:43]=harv_rk	#area cropped
#XXL[idx,44:56]=harv_ak	#harvested amount of crops
#XXL[idx,57:69]=harv_ik	#inputs			
#XXL[idx,70:82]=harv_gk	#gains

dev.off()