%wasa simulation results analysis tool
%conrad jackisch (cc) 01/2007
%ver. 0.1 beta

%this small script shall serve to analyze and visulize results from
%MODIFIED WASA simulations. it is aimed to meet the following concerns:

%VISUALIZE - weather and response of catchment (moisture dynamics,
%            discharge)
%CALCULATE - general water balance
%            response/decision of agent under ceratin constraints
%            productivity and portion of fallow land
%            band of realizations under same rules but different weather
%              scenarios
%STATISTICS- agent's concern > weather > crops/land cover > harvest

%- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

clear
profile on
kl=0;

%runi=2;
%runj=3;

alphabeta='abcdefghijklmnopqstuvwxyz';
    
    
for runj=1:12
firstrun=1;%needed for every alphabeta
for runi=1:9
tic;
run=['e:/data/conrad/conrad_simulations/simulations/wasa',num2str(runi),alphabeta(runj),'/'];
wasa_dir=[run '/'];   %directory that holds wasa files (end with slash)
%lump_dir='../LUMP_now/';   %directory that holds lump files (end with slash)

DISfile=[wasa_dir 'output/River_Flow.out']; %file containing daily river flow for all subs m3/s
PRECfile=[wasa_dir 'input/Time_series/rain_daily.dat']; %file containing daily precipitation for all subs
HARVESTfile=[wasa_dir 'output/tcwise_harvest.out']; %file containing harvest data
THETAfile=[wasa_dir 'output/daily_theta.out']; %file containing theta
ETPfile=[wasa_dir 'output/daily_actetranspiration.out']; %file containing actual ETP
OVERLANDfile=[wasa_dir 'output/daily_total_overlandflow.out']; %file containing subbasinwise overland flow (m3)
SUBSURFROfile=[wasa_dir 'output/daily_subsurface_runoff.out']; %file containing subbasinwise subsurface runoff (m3)



%catchment parameters:
catchsize=512154900;%catchment size in m2


%LOAD DATA FROM FILES
DIS=textread(DISfile,'','headerlines',2);%discharge: first 2 lines are IDs, first 2 columns are date; river flow m3/d for each sub
if firstrun==1
PREC=textread(PRECfile,'','headerlines',3);%precipitation: first 3 lines are IDs, first 2 columns are date
firstrun=0;
end
THETA=textread(PRECfile,'','headerlines',3);%daily subbasin wise theta (mm)
    THETA(:,length(THETA(1,:))+1)=mean(THETA(:,3:length(THETA(1,:))),2);%add mean of all water in catchment to THETA's last column
ETP=textread(ETPfile,'','headerlines',2);%daily subbasin wise ETP (mm)
    ETP(:,length(ETP(1,:))+1)=mean(ETP(:,3:length(ETP(1,:))),2);%add mean of all water in catchment to ETP's last column
HARVEST=textread(HARVESTfile,'','headerlines',2);%annual harvest
    %(1)year	(2)SUB	(3)LU	(4)TC	(5)SVC	(6)k(1)/r(2)	(7)area	(8)share in tc(%)	(9)crop	(10)inputs(RS/qint)	(11)gains(RS/qint)	(12)harvest(kg/ha)
OVERLAND=textread(OVERLANDfile,'','headerlines',2);%overland flow (m3)
SUBSURFRO=textread(SUBSURFROfile,'','headerlines',2);%subsurface flow (m3)

firstt=datenum(DIS(1,1), 1, 1);
lastt=datenum(DIS(length(DIS(:,1)),1),1,1)+DIS(length(DIS(:,1)),2);


%PLOT OF PRECIPITATION - DISCHARGE RELATIONSHIP
figure(1)
subplot(2,2,1:2)
hold off
plot(600-PREC(:,65),'Color','blue','LineWidth',1)
hold on
plot(DIS(:,67),'Color','red','LineWidth',1)
%plot(THETA(:,length(THETA(1,:)))/100,'Color','black','LineWidth',1)
title('SIMULATED DISCHARGE in m3/s from modifiedWASA')
xlabel(['time step as of ' datestr(firstt, 'dd-mmm-yyyy') ' in 6h lags until '  datestr(lastt, 'dd-mmm-yyyy')])
ylabel('discharge in m3/s _ rainfall in mm')

subplot(2,2,3:4)
hold off
plot(cumsum(PREC(:,65)/1000)*catchsize,'Color','blue','LineWidth',1)
hold on
plot(cumsum(DIS(:,67)*3600*24),'Color','red','LineWidth',1)
plot(cumsum(THETA(:,length(THETA(1,:)))/1000*catchsize),'Color','black','LineWidth',1)
plot(cumsum(ETP(:,length(ETP(1,:)))/1000*catchsize),'Color','green','LineWidth',1)
title('SIMULATED DISCHARGE in m3/s from modifiedWASA')
xlabel(['time step as of ' datestr(firstt, 'dd-mmm-yyyy') ' in 6h lags until '  datestr(lastt, 'dd-mmm-yyyy')])
ylabel('discharge in m3/s _ rainfall in mm')

%get cumulated yearly rain
RAIN(:,1)=PREC(:,1)-double(int32(PREC(:,1)/10000))*10000.;
RAIN(:,2)=PREC(:,10);
%convert year counter
THETA(:,length(THETA(1,:))+1)=THETA(:,1)-double(int32(THETA(:,1)/10000))*10000.;
PREC(:,length(PREC(1,:))+1)=PREC(:,1)-double(int32(PREC(:,1)/10000))*10000.;



                %output tex file for table
                fidr=fopen(['summary',num2str(runi),alphabeta(runj),'.tex'],'w+');
                dumstr='\documentclass [11pt,a4paper]{scrreprt}';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\usepackage[english]{babel}';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\usepackage[latin1]{inputenc}';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\usepackage[T1]{fontenc}';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\usepackage{array}';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\title{WASA SUMMARY OF SIMULATION}';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\begin{document}';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\maketitle';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='Summary from simulation of the Agroecosystem of the Mod catchment, MP, India using a modified WASA.';
                fprintf(fidr,'%s\n',dumstr);

                dumstr='\begin{table}[h!]';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\begin{tabular}{|l|l|l|l|l|l|l|l|} \hline';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='\multicolumn{8}{|c|}{ModifiedWASA Simulation Results}\\ \hline';
                fprintf(fidr,'%s\n',dumstr);
                dumstr='Year & Rain & Season & Crop & Area(ha) & Harvest(kg) & Gains(RS/quin) & Income(RS)\\ \hline';
                fprintf(fidr,'%s\n',dumstr);



for i=1:min(str2double(datestr(lastt,'yyyy'))-str2double(datestr(firstt,'yyyy')),50)
    my=i+str2double(datestr(firstt,'yyyy'))-1;
    %OVERLAND FLOW
    clear idx mm
    mm=length(OVERLAND(1,:));
    idx=find(OVERLAND(:,1)==my);
    idx=idx(mean(OVERLAND(idx,3:mm),2)~=0);
    overlandflow(1)=sum(sum(OVERLAND(idx,3:mm)));
    overlandflow(2)=mean(mean(OVERLAND(idx,3:mm)));
    overlandflow(3)=max(max(OVERLAND(idx,3:mm)));
    overlandflow(4)=var(mean(OVERLAND(idx,3:mm),2));
    overlandflow(5)=length(idx);
    %SUBSURFACE FLOW
    clear idx mm
    mm=length(SUBSURFRO(1,:));
    idx=find(SUBSURFRO(:,1)==my);
    idx=idx(mean(SUBSURFRO(idx,3:mm),2)~=0);
    subsurfaceflow(1)=sum(sum(SUBSURFRO(idx,3:mm)));
    subsurfaceflow(2)=mean(mean(SUBSURFRO(idx,3:mm)));
    subsurfaceflow(3)=max(max(SUBSURFRO(idx,3:mm)));
    subsurfaceflow(4)=var(mean(SUBSURFRO(idx,3:mm),2));
    subsurfaceflow(5)=length(idx);
    %THETA
    clear idx mm
    mm=length(THETA(1,:))-2;
    idx=find(THETA(:,length(THETA(1,:)))==my);
    %idx=idx(THETA(idx,3:mm)~=0);
    theta(1)=sum(sum(THETA(idx,3:mm)));
    theta(2)=mean(mean(THETA(idx,3:mm)));
    theta(3)=max(max(THETA(idx,3:mm)));
    theta(4)=var(mean(THETA(idx,3:mm),2));
    theta(5)=length(idx);
    %ETP
    clear idx mm
    mm=length(ETP(1,:))-1;
    idx=find(ETP(:,1)==my);
    %idx=idx(ETP(idx,3:mm)~=0);
    etp(1)=sum(sum(ETP(idx,3:mm)));
    etp(2)=mean(mean(ETP(idx,3:mm)));
    etp(3)=max(max(ETP(idx,3:mm)));
    etp(4)=var(mean(ETP(idx,3:mm),2));
    etp(5)=length(idx);
    %DISCHARGE
    clear idx mm
    mm=length(DIS(1,:));
    idx=find(DIS(:,1)==my);
    idx=idx(DIS(idx,mm)~=0);
    discharge(1)=(sum(DIS(idx,mm)));
    discharge(2)=(mean(DIS(idx,mm)));
    discharge(3)=(max(DIS(idx,mm)));
    discharge(4)=(var(DIS(idx,mm)));
    discharge(5)=length(idx);
    %RAIN
    clear idx mm
    mm=2;
    idx=find(RAIN(:,1)==my);
    idx=idx(RAIN(idx,2)>0);
    precipitation(1)=(sum(RAIN(idx,2)));
    precipitation(2)=(mean(RAIN(idx,2)));
    precipitation(3)=(max(RAIN(idx,2)));
    precipitation(4)=(var(RAIN(idx,2)));
    precipitation(5)=length(idx);

 kl=kl+1;   
   
    %ANALYSE HARVEST AND CROPPING and REPORT INTO FILE
    clear idx rain
    idx=find(RAIN(:,1)==my);
    rain=sum(RAIN(idx,2));
    fprintf(fidr,'%s\n','\hline');
    for k=1:2
    clear idx idx1
    idx=find(HARVEST(:,1)==my);
    idx1=find(HARVEST(idx,6)==k);
    crops=unique(HARVEST(idx(idx1),9));
    for j=1:length(crops)
        clear idx2 idx3 idx4
        %store crop
        crop(kl,j,k,1)=crops(j);
        idx2=find(HARVEST(:,1)==i+str2double(datestr(firstt,'yyyy'))-1);
        idx3=find(HARVEST(idx2,6)==k);
        idx4=find(HARVEST(idx2(idx3),9)==crops(j));
        %area cropped
        crop(kl,j,k,2)=sum(HARVEST(idx2(idx3(idx4)),7));
        %inputs/gains
        crop(kl,j,k,3)=HARVEST(idx2(idx3(idx4(1))),10);
        crop(kl,j,k,4)=HARVEST(idx2(idx3(idx4(1))),11);
        crop(kl,j,k,5)=crop(kl,j,k,4)-crop(kl,j,k,3);
        %harvest
        crop(kl,j,k,6)=mean(HARVEST(idx2(idx3(idx4)),12));
        crop(kl,j,k,7)=crop(kl,j,k,6)*crop(kl,j,k,2);
        %benefit
        crop(kl,j,k,8)=crop(kl,j,k,7)/100 * crop(kl,j,k,5);
        crop(kl,j,k,9)=my;
        crop(kl,j,k,10)=runj;
        crop(kl,j,k,11)=runi;
        if k==1
            season='kharif';
        else
            season='rabi';
        end
        dumstr=[num2str(i+str2double(datestr(firstt,'yyyy'))),' & ',num2str(rain),' & ',season,' & ',num2str(crop(kl,j,k,1)),' & ',num2str(crop(kl,j,k,2)/10000,'%10.1f'),' & ',num2str(crop(kl,j,k,7),'%10.1f'),' & ',num2str(crop(kl,j,k,5),'%10.1f'),' & ',num2str(crop(kl,j,k,8),'%10.1f'),'\\ \hline'];
        fprintf(fidr,'%s\n',dumstr);
    end
    end
    
%comprise all into one matrix...
%SUPERSTORE XXL
%[year decision_constraint scenario
%rain(1..3) discharge(1..3) etp(1..3) theta(1..3) subsurface flow(1..3)
%overland flow(1..3) season crop area harvest profit]

    XXL(kl,1)=i+str2double(datestr(firstt,'yyyy'))-1;
    XXL(kl,2)=runj;
    XXL(kl,3)=runi;
    XXL(kl,4:8)=precipitation;
    XXL(kl,9:13)=discharge;
    XXL(kl,14:18)=etp;
    XXL(kl,19:23)=theta;
    XXL(kl,24:28)=subsurfaceflow;
    XXL(kl,29:33)=overlandflow;
    
end



            dumstr='\end{tabular}';
            fprintf(fidr,'%s\n',dumstr);
            dumstr='\end{table}';
            fprintf(fidr,'%s',dumstr);
            dumstr='\end{document}';
            fprintf(fidr,'%s',dumstr);
            fclose(fidr);

toc
disp(['done run ',num2str(runi),alphabeta(runj),'.'])
end
end

% % % % % % % % % % % % % % % % % % % % % % % % % % %
%OK. NOW XXL and CROP EXIST TO PERFORM SOME ANALYSIS%
% % % % % % % % % % % % % % % % % % % % % % % % % % %

%CALCULATE LIKELINESS MATRIX FROM CROP

for iy=2000:2023
    idy=find(crop(:,1,1,9)==iy); %get kl of this instance
    for ia=1:9
        ida=find(crop(idy,1,1,11)==ia);
        for iw=1:12
            idw=find(crop(idy(ida),1,1,10)==iw); %get kl of this instance at kharif
            cropmx(iy,ia,iw,1,1:13)=0;
            cropic=int16(crop(idy(ida(idw)),:,1,1));
            cropmx(iy,ia,iw,1,cropic(cropic>0))=crop(idy(ida(idw)),(cropic>0),1,2)/catchsize;
            cropmx(iy,ia,iw,3,1)=idy(ida(idw));
            
            idw=find(crop(idy(ida),1,2,10)==iw); %get kl of this instance at rabi
            cropmx(iy,ia,iw,2,1:13)=0;
            cropic=int16(crop(idy(ida(idw)),:,2,1));
            cropmx(iy,ia,iw,2,cropic(cropic>0))=crop(idy(ida(idw)),(cropic>0),2,2)/catchsize;
            cropmx(iy,ia,iw,4,1)=idy(ida(idw));%store kl
        end
    end
end

ic=0;
s=1;%only kharif
for iy=2000:2023
    for ia=1:9
        for iw=1:12
            %for s=1:2
                ic=ic+1;
                cropchk1(1:13)=cropmx(iy,ia,iw,s,1:13);
                cropchk_coords=[iy ia iw];
                jc=0;
                for iy2=2000:2023
                    for ia2=1:9
                        for iw2=1:12
                            jc=jc+1;
                            cropchk2(1:13)=cropmx(iy2,ia2,iw2,s,1:13);
                            for icc=1:13
                                if cropchk1(icc)>0 && cropchk2(icc)>0 && isnan(cropchk1(icc))==0 && isnan(cropchk2(icc))==0
                                    cropchk3(icc)=(min([cropchk1(icc) cropchk2(icc)])/max([cropchk1(icc) cropchk2(icc)])) * (sum([cropchk1(icc) cropchk2(icc)])/2);
                                else
                                    cropchk3(icc)=0;
                                end    
                            end
                            CROPMX(ic,jc,1)=sum(cropchk3); %Likeliness matrix !problem of generated idicees
                            %get vectors for indicees of same
                            %years/weather/agent/season
                            CROPMX(ic,jc,2:4)=cropchk_coords;
                            CROPMX(ic,jc,5:8)=[iy2 ia2 iw2 s];
                            CROPMX(ic,jc,9)=cropmx(iy,ia,iw,s+2,1);%store kl for further indication
                            CROPMX(ic,jc,10)=cropmx(iy2,ia2,iw2,s+2,1);
                        end
                    end
                end
           %end
        end
    end
end
s=2; %only rabi 
for iy=2000:2023
    for ia=1:9
        for iw=1:12
            %for s=1:2
                ic=ic+1;
                cropchk1(1:13)=cropmx(iy,ia,iw,s,1:13);
                cropchk_coords=[iy ia iw];
                jc=0;
                for iy2=2000:2023
                    for ia2=1:9
                        for iw2=1:12
                            jc=jc+1;
                            cropchk2(1:13)=cropmx(iy2,ia2,iw2,s,1:13);
                            for icc=1:13
                                if cropchk1(icc)>0 && cropchk2(icc)>0 && isnan(cropchk1(icc))==0 && isnan(cropchk2(icc))==0
                                    cropchk3(icc)=(min([cropchk1(icc) cropchk2(icc)])/max([cropchk1(icc) cropchk2(icc)])) * (sum([cropchk1(icc) cropchk2(icc)])/2);
                                else
                                    cropchk3(icc)=0;
                                end    
                            end
                            CROPMX1(ic,jc,1)=sum(cropchk3); %Likeliness matrix !problem of generated idicees
                            %get vectors for indicees of same
                            %years/weather/agent/season
                            CROPMX1(ic,jc,2:4)=cropchk_coords;
                            CROPMX1(ic,jc,5:8)=[iy2 ia2 iw2 s];
                            CROPMX1(ic,jc,9)=cropmx(iy,ia,iw,s+2,1);%store kl for further indication
                            CROPMX1(ic,jc,10)=cropmx(iy2,ia2,iw2,s+2,1);
                        end
                    end
                end
           %end
        end
    end
end



figure(2)
surf(CROPMX(:,:,1))
figure(3)
surf(CROPMX1(:,:,1))

%SHOW RESULTS
%>similarity of results of the same weather (whole 25 years)
        figure(2)
        hold on
        for iw=1:12
            idx1=find(CROPMX(:,1,4)==iw);
            idx2=find(CROPMX(1,:,7)==iw);
            dummy1=ones(1,length(idx2));
            for ii=1:length(idx1)
                scatter3(dummy1*idx1(ii),idx2,CROPMX(idx1(ii),idx2,1),iw)
            end
        end
        title('Similarity of results of simulations depending on weather scenarios')
        
%>similarity of results of the same weather (single years)
        idx_xs=find(XXL(:,4)<350);
        idx_s=find(XXL(:,4)>=350 && XXL(:,4)<550);
        idx_m=find(XXL(:,4)>=550 && XXL(:,4)<800);
        idx_l=find(XXL(:,4)>=800 && XXL(:,4)<1000);
        idx_xl=find(XXL(:,4)>=1000);                %precipitation sum > get indicees of similar weather in terms of annual precipitation

        figure(3)
        hold on
        for ix=1:5
            if ix==1
                idx_xx=idx_xs;
            elseif ix==2
                idx_xx=idx_s;
            elseif ix==3
                idx_xx=idx_m;
            elseif ix==4
                idx_xx=idx_l;
            elseif ix==5
                idx_xx==idx_xl;
            end
            idx1=find(CROPMX(:,1,9)==idx_xx(1));
            for iw=2:length(idx_xx)
                idx2=find(CROPMX(:,1,9)==idx_xx(iw));
                idx1=[idx1 idx2];
            end
            idx2=find(CROPMX(1,:,9)==idx_xx(1));
            for iw=2:length(idx_xx)
                idx3=find(CROPMX(1,:,9)==idx_xx(iw));
                idx2=[idx2 idx3];
            end
            dummy1=ones(1,length(idx2));
            for ii=1:length(idx1)
                scatter3(dummy1*idx1(ii),idx2,CROPMX(idx1(ii),idx2,1),ix)
            end
        end
        title('Similarity of results of simulations depending on precipitation in certain year')

%>similarity of results of the same agent's constraint
        figure(4)
        hold on
        for ia=1:9
            idx1=find(CROPMX(:,1,3)==ia);
            idx2=find(CROPMX(1,:,6)==ia);
            dummy1=ones(1,length(idx2));
            for ii=1:length(idx1)
                scatter3(dummy1*idx1(ii),idx2,CROPMX(idx1(ii),idx2,1),ia)
            end
        end
        title('Similarity of results of simulations depending on constraint of agent')  
        
%>similarity of results of similar harvest results
        %classify harvest
            harv_mean=mean(mean(CROPMX(:,:,
        figure(5)
        hold on
        for ia=1:3
            idx1=find(CROPMX(:,1,3)==ia);
            idx2=find(CROPMX(1,:,6)==ia);
            dummy1=ones(1,length(idx2));
            for ii=1:length(idx1)
                scatter3(dummy1*idx1(ii),idx2,CROPMX(idx1(ii),idx2,1),ia)
            end
        end
        title('Similarity of results of simulations depending on constraint of agent')  
        


%>is similarity of harvest results depending on agent?
%>is similarity of harvest results depending on weather?
%>identify good harvest results throughout a 25 year period. why are they good?

%>what strategy keeps most water in the basin?
%>what strategy keeps the maximal flows minimal?
%>what strategy has the least variance in flows?

                
                




profile viewer




    

