%weather generator for jhabua district
%based on meteodata input generator from data from indore and jhabua

%v1.0 including stull/droogers/jackisch solar radiation calculation
%cc conrad jackisch 2007

%clear

profile on

%%% % % % % % % % % % % % % % % % % % % % % % % % % % % %%%%
%Inserted from etp_hargreaves. dont get confused about this%
%%% % % % % % % % % % % % % % % % % % % % % % % % % % % %%%%

%Evaporation Analysis Tool
%
%Functions  (a) read data from file as traing database
%           (b) fit Modified Hargreaves
%           (c) crossvalidation and plotting
%           (d) apply MH on new Input Data


%Introduction of functions:
%
%PM: PET = [(0.408 * Teta * (Rn-G) + gamma(900/(Tavg+273)) * u2* (es-ea)] /
%           Teta + gamma * (1 + 0.34*u2)

%MH: HET = 0.0013 * 0.408 * RA * (Tavg+17.0) * (TD-0.0123 P) ^ 0.76
%
%PM see kovoor06 page 11
%
%RA = Extraterrestial Radiation in MJ*m^2*d^1
%Tavg = mean Temperature
%TD = Temperature Range = Tmax-Tmin
%P = Precipitation



%#################################
%#   reading weather data        #
%#################################


clear;

%reading data from file tmax tmin EP Prec
fid = fopen('../precipitation/weatherXnonan.csv');
filestore = fscanf(fid,'%g %g %g %g %g\n',[5 inf]);
filestore = filestore';
fclose(fid)

day=filestore(:,1);
Tmax=filestore(:,2);
Tmin=filestore(:,3);
EP=filestore(:,5);
Prec=filestore(:,4);





%#################################
%#   terrestial radiation        #
%#################################

%parametrization after stull:
%Transmitted short wave radiation RA (check units; check daysum!!!)
%Kin = S * TK * sin(Psi)
%TK = (0.6 + 0.2 * sin(Psi)) * (1 - 0.4 * sigCH) * (1 - 0.7 * sigCM)
%      * (1 - 0.4 * sigCL)
%sin(Psi) = sin(LAT)*sin(SDA) - cos(LAT)*cos(SDA)*cos [((pi*tUTC)/12)-LON]
%SDA = ToC * cos { [2*pi*(d-dr)] / dy}

%ToC=23.45=0.409rad
%d<-day of the year
%dr<-day of summer solstice=173
%dy<-no. of days in year=365.25



%parametrization after chuanyan et. al (clouds not considered here!)
%PET=0.0023*S0*dT*(Tmean+17.8)
%thus S0=0.408*RA
%
%---> substitute S0 in modified Hargreaves:
%PET= 0.0013 * S0 * (Tmean+17.0) * (dT - (0.0123 * P))^0.76
%S0= 15.392 * dr * (t * sin(LAT) * sin(decl) + cos(LAT) * cos(decl) * sin(t))
%dr= 1 + 0.033 * cos((2*pi)/(365*J))
%t= arccos(-tan(LAT) * tan(decl))
%decl= 0.4093 * sin(((2*pi)/365)*J - 1.405)
%      ''''''
%       ToC


% ################ PARAMETERS ################

LAT=22.4;
%LON=-74.3*pi/180;
%ToC=23.45*pi/180;
S=1370;%W/m^2; Kyle 1985
cor1=-5.7507;

% ## CALCULATION OF LOOK-UP TABLE FOR S0 #####

d=1

for d=1:365
    %chuanyan paramerization
    decl = 0.4093 * sin(((2*pi)/365)*d - 1.405);
    dr = 1 + 0.033 * cos((2*pi)/(365*d));
    t= acos(-tan(LAT) * tan(decl));
    S0(d)= 15.392 * dr * (t * sin(LAT) * sin(decl) + cos(LAT) * cos(decl) * sin(t));
    %MJ/m2/d

    %stull parametrization
    SDA = 0.4093 * cos([2*pi*(d-173)]/365);
    sP = sin(LAT)*sin(SDA) - cos(LAT)*cos(SDA); %*cos [((pi*tUTC)/12)-LON] seems to be downscaling below day
    TKsun = (0.6 + 0.2 * sP);
    TKcloud = (0.6 + 0.2 * sP) * (1 - 0.4 * 0.8) * (1 - 0.7 * 0.8) * (1 - 0.4 * 0.8);
    TKmed = (0.6 + 0.2 * sP) * (1 - 0.4 * 0.3) * (1 - 0.7 * 0.3) * (1 - 0.4 * 0.3);
    RA(1,d) = S * TKsun * sP * (1e-6)*(24*60*60) /cor1;
    RA(2,d) = S * TKmed * sP * (1e-6)*(24*60*60) /cor1;
    RA(3,d) = S * TKcloud * sP * (1e-6)*(24*60*60) /cor1;
    %W/m2
end

betan=15.4;
alphan=2.9;
deltan=9.6;

% #### PARATETRIZATION OF MOD HARGREAVES #####


%#################################
%#   Hargreaves Modified         #
%#################################

% HET = 0.0013 * S0 * (Tavg + 17.0) * (TD-0.0123 P) ^ 0.76
%       ''''''                ''''
%       fitting              fitting



i=2;
w1=0.5;
w2=1-w1;
betay=betan;
gammay=alphan;
deltay=deltan;

% Calculating Hargreaves (PET) and modified Hargreves (HET)

for i=2:(length(Tmax)-1)

    %### CALCULATION #######

    TP = (Tmax(i)-Tmin(i)) - (0.0123 * Prec(i));
    if TP<0
        TP=0;
    end
    Tmean=mean([Tmax(i) Tmin(i)]);
    %after chuanyan/droogers
    HETc(i) = 0.0013 * S0(day(i)) * (exp((Tmean/gammay)-deltay) + (w1*Tmax(i) + w2*Tmin(i)) + betay) * ((TP) ^ 0.76);%introduce weighted means
    PETc(i) = 0.0023 * S0(day(i)) * ((Tmax(i)-Tmin(i)) ^ 0.5) * ((w1*Tmax(i) + w2*Tmin(i)) + 17.8);

    %modify radiation for clouds estimated from precipitation on day
    %and day before
    if Prec(i)>30 %cloudy
        Smod=S0(day(i))*(1 - 0.4 * 0.8) * (1 - 0.7 * 0.8) * (1 - 0.4 * 0.8); %modified approach after stull to cloud effect parameterisation
    elseif (Prec(i-1)+Prec(i)+Prec(i+1))<10 %relatively sunny
        Smod=S0(day(i));
    else Smod=S0(day(i))* (1 - 0.4 * 0.2) * (1 - 0.7 * 0.2) * (1 - 0.4 * 0.2); %medium partly cloudy
    end

    HETcm(i) = 0.0013 * Smod * (exp((Tmean/gammay)-deltay) + (w1*Tmax(i) + w2*Tmin(i)) + betay) * ((TP) ^ 0.76);

    %after stull/droogers
    if Prec(i)>20                %estimating clouds
        RAD=RA(3,day(i));
    elseif (Prec(i-1)+Prec(i)+Prec(i+1))<8
        RAD=RA(1,day(i));
    else RAD=RA(2,day(i));
    end
    HETs(i) = 0.0013 * RAD * (1.3*(w1*Tmax(i) + w2*Tmin(i)) + 8.5) * ((TP) ^ 0.76);
    PETs(i) = 0.0023 * RAD * ((Tmax(i)-Tmin(i)) ^ 0.5) * ((w1*Tmax(i) + w2*Tmin(i)) + 17.8);

    %### COMPARISON ########

    div(1,i)= EP(i) + HETc(i); %positive because of negative HET
    div(2,i)= EP(i) + PETc(i);
    div(3,i)= EP(i) + HETcm(i);
    div(4,i)= EP(i) + HETs(i);
    div(5,i)= EP(i) + PETs(i);

end

    
    
%HERE IT ALL BEGINS:
%############### SEEDING #####################
nosim=1; %no. of simulations
noyears=25;%no. of years to generate
%#############################################



%get hymo.dat from make_wasa_input (see my input generator 2006 and franke et al. 2006)
hymo=textread('hymo.dat','','headerlines',2);
hymoorder=hymo(:,1);

%alirajpur data
%NOT YET USED
maxt=dlmread('maxtemp.dat','\t');
mint=dlmread('mintemp.dat','\t');
humid=dlmread('humid.dat','\t');

%structure: (year,month) and @ humid (year, month morning afternoon...)
indore=dlmread('indore.dat','\t');
m=length(indore(1,:))+1;
for i=1:length(indore(:,1))
    indore(i,m)=datenum(indore(i,1), indore(i,2), indore(i,3));
    indore(i,m+1)=datenum(2000, indore(i,2), indore(i,3)) - datenum(1999, 12, 31); %julian day of year
end

%dlmwrite('indoremod',indore,'delimiter', '\t', 'precision', '%.0f');

prec=dlmread('prec_all.csv',';');%read precipitation data
m=length(prec(1,:))+1;
for i=1:length(prec(:,1))
    if prec(i,3) < 10
        prec(i,3)=prec(i,3)+2000;
    else prec(i,3)=prec(i,3)+1900;
    end
    prec(i,m)=datenum(prec(i,3), prec(i,1), prec(i,2));
end

jhabuaw=dlmread('jhabuaKVK.dat','\t');%get weekly data from KVK-station jahbua
%generate daily data
for i=1:length(jhabuaw(:,1))
    j=((i-1)*7)+1;
    jhabua(j,1)=datenum(jhabuaw(i,2), 1, 1)+((jhabuaw(i,1)-1)*7);%datestamp
    jhabua(j,5)=((jhabuaw(i,1)-1)*7)+1;%julian day of year
    jhabua(j+1,1)=jhabua(j,1)+1;
    jhabua(j+2,1)=jhabua(j,1)+2;
    jhabua(j+3,1)=jhabua(j,1)+3;
    jhabua(j+4,1)=jhabua(j,1)+4;
    jhabua(j+5,1)=jhabua(j,1)+5;
    jhabua(j+6,1)=jhabua(j,1)+6;

    jhabua(j:j+6,2)=jhabuaw(i,3);%max temp
    jhabua(j:j+6,3)=jhabuaw(i,4);%min temp
end

%transfer daily prec data of jhabua to jhabua matrix
m=length(prec(1,:));
for i=1:length(jhabua(:,1))
    idx=find(prec(:,m)==jhabua(i,1));
    if idx
        jhabua(i,4)=prec(idx,4);
    else jhabua(i,4)=0;
    end
end


%get subbasins and distances from grass:
%run r.distance -l maps=SUBBASINS_LUMP,prec_stations > distances.txt
%1=megnaghar, 2=jhabua, 3=ranapur, 4=udaighar
sub_ini=dlmread('distances.txt','\t');
subs(:,1)=hymoorder;
for i=1:length(subs(:,1))
    idx=find(sub_ini(:,1)==subs(i));
    refsum=sum(sub_ini(idx,3));
    for k=1:3
        j=idx(k);
        subs(i,k+1)=sub_ini(j,3)/refsum;
    end
    if sum(subs(i,2:4))>1.05 || sum(subs(i,2:4))<0.95
        disp(['there was an error precessing weights at subbasin ',num2str(subs(i,1))])
        disp(['weights are ',num2str(subs(i,2)),num2str(subs(i,3)),num2str(subs(i,4))])%,num2str(subs(i,5))])
    end
end


%WARNING!
%needs to run ep_hargreaves before plotting this!!!
%plots of examples of realizations
figure(1)
title('Examples of EP, ETP, Precipitation, S(0) Relation')

subplot(2,3,1)
hold off
plot(-HETc(1:365))
hold on
plot(indore(1:365,5)/5,'Color','magenta')
plot(indore(1:365,10),'Color','red')
plot(indore(1:365,7)/5,'Color','green')
plot(-S0(180:365),'Color','black')
plot(185:364,-S0(1:180),'Color','black')
axis([0 365 0 22])
title('Jul 1992 - Jun 1993')

subplot(2,3,2)
hold off
plot(-HETc(366:366+364))
hold on
plot(indore(366:366+364,4)/5,'Color','magenta')
plot(indore(366:366+364,10),'Color','red')
plot(indore(366:366+364,7)/5,'Color','green')
plot(-S0(180:365),'Color','black')
plot(185:364,-S0(1:180),'Color','black')
axis([0 365 0 22])
title('Jul 1993 - Jun 1994')

subplot(2,3,3)
hold off
plot(-HETc(731:731+364))
hold on
plot(indore(731:731+364,4)/5,'Color','magenta')
plot(indore(731:731+364,10),'Color','red')
plot(indore(731:731+364,7)/5,'Color','green')
plot(-S0(180:365),'Color','black')
plot(185:364,-S0(1:180),'Color','black')
axis([0 365 0 22])
title('Jul 1994 - Jun 1995')

subplot(2,3,4)
hold off
plot(-HETc(1096:1096+364))
hold on
plot(indore(1096:1096+364,4)/5,'Color','magenta')
plot(indore(1096:1096+364,10),'Color','red')
plot(indore(1096:1096+364,7)/5,'Color','green')
plot(-S0(180:365),'Color','black')
plot(185:364,-S0(1:180),'Color','black')
axis([0 365 0 22])
title('Jul 1995 - Jun 1996')

subplot(2,3,5)
hold off
plot(-HETc(1461:1461+364))
hold on
plot(indore(1461:1461+364,4)/5,'Color','magenta')
plot(indore(1461:1461+364,10),'Color','red')
plot(indore(1461:1461+364,7)/5,'Color','green')
plot(-S0(180:365),'Color','black')
plot(185:364,-S0(1:180),'Color','black')
axis([0 365 0 22])
title('Jul 1996 - Jun 1997')

subplot(2,3,6)
hold off
plot(-HETc(1825:1825+364))
hold on
plot(indore(1825:1825+364,4)/5,'Color','magenta')
plot(indore(1825:1825+364,10),'Color','red')
plot(indore(1825:1825+364,7)/5,'Color','green')
plot(-S0(180:365),'Color','black')
plot(185:364,-S0(1:180),'Color','black')
axis([0 365 0 22])
title('Jul 1997 - Jun 1998')




%''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
%BAND of reasonable data calculation
%get bounds
clear rainidx
for i=1:366
    clear idxx idx
    idxx=find(indore(:,m+1)==i);
    k=1;
    ki=1;
    for j=1:length(idxx)
        if isnan(indore(idxx(j),4))<1 && isempty(indore(idxx(j),4))<1 && isnan(indore(idxx(j),5))<1 && isempty(indore(idxx(j),5))<1 && isnan(indore(idxx(j),6))<1 && isempty(indore(idxx(j),6))<1
            idx(k)=idxx(j);
            k=k+1;
        end
        if isnan(indore(idxx(j),7))<1 && isempty(indore(idxx(j),7))<1
            idxi(ki)=idxx(j);
            ki=ki+1;
        end
    end
    pEx(i)=length(idxi);%only to scale prec likeliness according to years reagarded


    Btmaxd(i,1)=max(indore(idx,4));
    Btmaxd(i,2)=min(indore(idx,4));
    Btmaxd(i,3)=mean(indore(idx,4));
    if isnan(Btmaxd(i,3))
        disp('error')
    end

    Btmind(i,1)=max(indore(idx,5));
    Btmind(i,2)=min(indore(idx,5));
    Btmind(i,3)=mean(indore(idx,5));
    if isnan(Btmind(i,3))
        disp('error')
    end

    clear tmeandummy
    for j=1:length(idx)
        tmeandummy(j)=mean([indore(idx(j),4) indore(idx(j),5)]);
    end
    Btmd(i,1)=max(tmeandummy);
    Btmd(i,2)=min(tmeandummy);
    Btmd(i,3)=mean(tmeandummy);
    if isnan(Btmd(i,3))
        disp('error')
    end

    Bhumidd(i,1)=max(indore(idx,6));
    Bhumidd(i,2)=min(indore(idx,6));
    Bhumidd(i,3)=mean(indore(idx,6));
    if isnan(Bhumidd(i,3))
        disp('error')
    end

    if max(isempty(idxi))<1 && max(isnan(idxi))<1
        Braind(i,1)=max(indore(idxi,7));
        Braind(i,2)=min(indore(idxi,7));
        Braind(i,3)=mean(indore(idxi,7));
        Braind(i,4)=0;
        for ic=1:length(idxi)
            if indore(idxi(ic),7)>0
                Braind(i,4)=Braind(i,4)+1;
            end
        end
        if isnan(Bhumidd(i,3))
            disp('error')
        end
    else Braind(i,:)=0;
    end

end

for rep=1:5
    for i=6:361
        Btmaxd(i,1)=mean(Btmaxd(i-5:i+5,1));
        Btmaxd(i,2)=mean(Btmaxd(i-5:i+5,2));
        Btmaxd(i,3)=mean(Btmaxd(i-5:i+5,3));
        Btmind(i,1)=mean(Btmind(i-5:i+5,1));
        Btmind(i,2)=mean(Btmind(i-5:i+5,2));
        Btmind(i,3)=mean(Btmind(i-5:i+5,3));
        Btmd(i,1)=mean(Btmd(i-5:i+5,1));
        Btmd(i,2)=mean(Btmd(i-5:i+5,2));
        Btmd(i,3)=mean(Btmd(i-5:i+5,3));
        Bhumidd(i,1)=mean(Bhumidd(i-5:i+5,1));
        Bhumidd(i,2)=mean(Bhumidd(i-5:i+5,2));
        Bhumidd(i,3)=mean(Bhumidd(i-5:i+5,3));
        Braind(i,1)=mean(Braind(i-5:i+5,1));
        Braind(i,2)=mean(Braind(i-5:i+5,2));
        Braind(i,3)=mean(Braind(i-5:i+5,3));
        Braind(i,4)=mean(Braind(i-5:i+5,4));
    end

    superix=[356 357 358 359 360 361 362 363 364 365 366 1 2 3 4 5 6 7 8 9 10];
    for j=1:10
        ix=superix(j:j+10);
        Btmaxd(ix(6),1)=mean(Btmaxd(ix,1));
        Btmaxd(ix(6),2)=mean(Btmaxd(ix,2));
        Btmaxd(ix(6),3)=mean(Btmaxd(ix,3));
        Btmind(ix(6),1)=mean(Btmind(ix,1));
        Btmind(ix(6),2)=mean(Btmind(ix,2));
        Btmind(ix(6),3)=mean(Btmind(ix,3));
        Btmd(ix(6),1)=mean(Btmd(ix,1));
        Btmd(ix(6),2)=mean(Btmd(ix,2));
        Btmd(ix(6),3)=mean(Btmd(ix,3));
        Bhumidd(ix(6),1)=mean(Bhumidd(ix,1));
        Bhumidd(ix(6),2)=mean(Bhumidd(ix,2));
        Bhumidd(ix(6),3)=mean(Bhumidd(ix,3));
        Braind(ix(6),1)=mean(Braind(ix,1));
        Braind(ix(6),2)=mean(Braind(ix,2));
        Braind(ix(6),3)=mean(Braind(ix,3));
        Braind(ix(6),4)=mean(Braind(ix,4));
    end
end

for i=3:364
    Btmax(i,1)=median(Btmaxd(i-2:i+2,1));
    Btmax(i,2)=median(Btmaxd(i-2:i+2,2));
    Btmax(i,3)=median(Btmaxd(i-2:i+2,3));
    Btmin(i,1)=median(Btmind(i-2:i+2,1));
    Btmin(i,2)=median(Btmaxd(i-2:i+2,2));
    Btmin(i,3)=median(Btmaxd(i-2:i+2,3));
    Btm(i,1)=median(Btmd(i-2:i+2,1));
    Btm(i,2)=median(Btmd(i-2:i+2,2));
    Btm(i,3)=median(Btmd(i-2:i+2,3));
    Bhumid(i,1)=median(Bhumidd(i-2:i+2,1));
    Bhumid(i,2)=median(Bhumidd(i-2:i+2,2));
    Bhumid(i,3)=median(Bhumidd(i-2:i+2,3));
    Brain(i,1)=median(Braind(i-2:i+2,1));
    Brain(i,2)=median(Braind(i-2:i+2,2));
    Brain(i,3)=median(Braind(i-2:i+2,3));
    Brain(i,4)=median(Braind(i-2:i+2,4));
end

for j=1:4
    if j==1
        ix=[365 366 1 2 3];
    elseif j==2
        ix=[366 1 2 3 4];
    elseif j==3
        ix=[364 365 366 1 2];
    elseif j==4
        ix=[363 364 365 366 1];
    end

    Btmax(ix(3),1)=median(Btmaxd(ix,1));
    Btmax(ix(3),2)=median(Btmaxd(ix,2));
    Btmax(ix(3),3)=median(Btmaxd(ix,3));
    Btmin(ix(3),1)=median(Btmind(ix,1));
    Btmin(ix(3),2)=median(Btmind(ix,2));
    Btmin(ix(3),3)=median(Btmind(ix,3));
    Btm(ix(3),1)=median(Btmd(ix,1));
    Btm(ix(3),2)=median(Btmd(ix,2));
    Btm(ix(3),3)=median(Btmd(ix,3));
    Bhumid(ix(3),1)=median(Bhumidd(ix,1));
    Bhumid(ix(3),2)=median(Bhumidd(ix,2));
    Bhumid(ix(3),3)=median(Bhumidd(ix,3));
    Brain(ix(3),1)=median(Braind(ix,1));
    Brain(ix(3),2)=median(Braind(ix,2));
    Brain(ix(3),3)=median(Braind(ix,3));
    Brain(ix(3),4)=median(Braind(ix,4));
end
Brain(:,4)=Brain(:,4)/median(pEx);

figure(2)
subplot(2,3,1)
hold off
plot(Btmax(:,1))
hold on
plot(Btmax(:,2))
plot(Btmax(:,3),'Color','black')
title('T max')

subplot(2,3,2)
hold off
plot(Btmin(:,1))
hold on
plot(Btmin(:,2))
plot(Btmin(:,3),'Color','black')
title('T min')

subplot(2,3,3)
hold off
plot(Btm(:,1))
hold on
plot(Btm(:,2))
plot(Btm(:,3),'Color','black')
title('T mean')

subplot(2,3,4)
hold off
plot(Bhumid(:,1))
hold on
plot(Bhumid(:,2))
plot(Bhumid(:,3),'Color','black')
title('Humid')

subplot(2,3,5)
hold off
plot(Brain(:,1))
hold on
plot(Brain(:,2))
plot(Brain(:,3),'Color','black')
title('Rain')

subplot(2,3,6)
hold off
plot(Brain(:,4))
title('Rain Likeliness')


%RAINEVENTS>>GET NO OF RAINEVENTS UNDER CONDITIONS...
pointer=zeros(10,1);
for i=1:length(indore(:,7))
    if indore(i,7)>0
        idxy=indore(i,1)-indore(1,1)+1;
        idxd=datenum(0,indore(i,2),indore(i,3));
        if pointer(idxy)>0
            totalrainstat(idxy,1)=totalrainstat(idxy,1)+1;
            if idxy==1
                rains1=[rains1 i];
            elseif idxy==2
                rains2=[rains2 i];
            elseif idxy==3
                rains3=[rains3 i];
            elseif idxy==4
                rains4=[rains4 i];
            elseif idxy==5
                rains5=[rains5 i];
            elseif idxy==6
                rains6=[rains6 i];
            elseif idxy==7
                rains7=[rains7 i];
            elseif idxy==8
                rains8=[rains8 i];
            elseif idxy==9
                rains9=[rains9 i];
            elseif idxy==10
                rains10=[rains10 i];
            end

        else totalrainstat(idxy,1)=1;
            if idxy==1
                rains1=1;
            elseif idxy==2
                rains2=1;
            elseif idxy==3
                rains3=1;
            elseif idxy==4
                rains4=1;
            elseif idxy==5
                rains5=1;
            elseif idxy==6
                rains6=1;
            elseif idxy==7
                rains7=1;
            elseif idxy==8
                rains8=1;
            elseif idxy==9
                rains9=1;
            elseif idxy==10
                rains10=1;
            end
            pointer(idxy)=1;
        end
    end
end
for i=1:10
    clear rains
    if i==1
        rains(1,:)=rains1;
    elseif i==2
        rains(1,:)=rains2;
    elseif i==3
        rains(1,:)=rains3;
    elseif i==4
        rains(1,:)=rains4;
    elseif i==5
        rains(1,:)=rains5;
    elseif i==6
        rains(1,:)=rains6;
    elseif i==7
        rains(1,:)=rains7;
    elseif i==8
        rains(1,:)=rains8;
    elseif i==9
        rains(1,:)=rains9;
    elseif i==10
        rains(1,:)=rains10;
    end

    rains(2,:)=indore(rains,7);
    rains=sortrows(rains',2)';
    a=length(rains(1,:));
    totalrainstat(i,2)=int8(a/5);
    totalrainstat(i,3)=max(indore(rains(1,1:int8(a/5)),7));
    totalrainstat(i,4)=min(indore(rains(1,1:int8(a/5)),7));
    totalrainstat(i,5)=sum(indore(rains(1,1:int8(a/5)),7));
    totalrainstat(i,6)=max(indore(rains(1,int8(a/5)+1:int8(a/5)*2),7));
    totalrainstat(i,7)=min(indore(rains(1,int8(a/5)+1:int8(a/5)*2),7));
    totalrainstat(i,8)=sum(indore(rains(1,int8(a/5)+1:int8(a/5)*2),7));
    totalrainstat(i,9)=max(indore(rains(1,int8(a/5)*2+1:int8(a/5)*3),7));
    totalrainstat(i,10)=min(indore(rains(1,int8(a/5)*2+1:int8(a/5)*3),7));
    totalrainstat(i,11)=sum(indore(rains(1,int8(a/5)*2+1:int8(a/5)*3),7));
    totalrainstat(i,12)=max(indore(rains(1,int8(a/5)*3+1:int8(a/5)*4),7));
    totalrainstat(i,13)=min(indore(rains(1,int8(a/5)*3+1:int8(a/5)*4),7));
    totalrainstat(i,14)=sum(indore(rains(1,int8(a/5)*3+1:int8(a/5)*4),7));
    totalrainstat(i,15)=max(indore(rains(1,int8(a/5)*4+1:int8(a)),7));
    totalrainstat(i,16)=min(indore(rains(1,int8(a/5)*4+1:int8(a)),7));
    totalrainstat(i,17)=sum(indore(rains(1,int8(a/5)*4+1:int8(a)),7));
    a=[5 8 11 14 17];
    totalrainstat(i,18)=sum(totalrainstat(i,a));
end


%'''''''''''''''''''''''''''''''''''''''''''''''''''''''
for iii=1:nosim
    tic
    clear weather
    for ii=1:noyears
        %yearly sum or rain between 350 and 1400 mm
        %depending on this distribution of rain event character
        %input for simulation
        c=randperm(3);
        if c(1)==1
            a=350; b=550;
            raintot=a+(b-a)*rand(1);
        elseif c(1)==3
            a=850; b=1400;
            raintot=a+(b-a)*rand(1);
        else a=550; b=850;
            raintot=a+(b-a)*rand(1);
        end


        ridx=find(abs(totalrainstat(:,18)-raintot)==min(abs(totalrainstat(:,18)-raintot)));

        rainevents=[5*totalrainstat(ridx,2) 4*totalrainstat(ridx,2) 3*totalrainstat(ridx,2) 2*totalrainstat(ridx,2) totalrainstat(ridx,2)];



        %precipitation
        RS(1)=find(Brain(:,1)>=totalrainstat(ridx,13),1,'first');
        RS(2)=find(Brain(:,1)>=totalrainstat(ridx,13),1,'last'); %define rainy season for intensive rain falls
        Rs(1)=max(find(Brain(:,1)>=totalrainstat(ridx,7),1,'first'));
        Rs(2)=max(find(Brain(:,1)>=totalrainstat(ridx,7),1,'last')); %define rainy season for normal rain falls

        %assign days with rain
        Brain(:,5)=int16(Brain(:,4)/0.01);
        rainpool=median(find(Brain(:,4)==max(Brain(:,4))));%seed for rainpool
        for i=1:365
            ibreak=Brain(i,5);
            while ibreak>0
                rainpool=[rainpool i];
                ibreak=ibreak-1;
            end
        end
        draw=randperm(length(rainpool));
        i=1;
        j=1;
        rain=[];
        while j<rainevents(1)+1
            clear check
            check=find(rain==rainpool(draw(i)));
            if isempty(check)
                rain(j)=rainpool(draw(i)); %days with rainfall
                j=j+1;
            else i=i+1;
            end
        end

        %distribute precipitation to events
        %intensive prec
        irain=find(rain>RS(1) & rain<RS(2));
        idx=randperm(length(irain));

        intenserain1=zeros(1,rainevents(5));
        for i=1:rainevents(5)
            intenserain1(i)=rain(irain(idx(i)));
        end
        %remove these events from rain for further consideration
        for i=1:length(intenserain1)
            idx=find(rain==intenserain1(i));
            if isempty(idx)<1
                rain(i)=NaN;
            end
        end
        rain=rain(~isnan(rain));
        irain=find(rain>RS(1) & rain<RS(2));

        idx=randperm(length(irain));
        intenserain=zeros(1,rainevents(5));
        for i=1:rainevents(5)
            intenserain(i)=rain(irain(idx(i)));
        end
        %remove these events from rain for further consideration
        for i=1:length(intenserain)
            idx=find(rain==intenserain(i));
            if isempty(idx)<1
                rain(i)=NaN;
            end
        end
        rain=rain(~isnan(rain));

        %medium prec
        irain=find(rain>Rs(1) & rain<Rs(2));
        idx=randperm(length(irain));
        mediumrain1=zeros(1,rainevents(5));
        for i=1:rainevents(3)-rainevents(4)
            mediumrain1(i)=rain(irain(idx(i)));
        end
        %remove these events from rain for further consideration
        for i=1:length(mediumrain1)
            idx=find(rain==mediumrain1(i));
            if isempty(idx)<1
                rain(i)=NaN;
            end
        end
        rain=rain(~isnan(rain));
        irain=find(rain>Rs(1) & rain<Rs(2));
        mediumrain=zeros(1,rainevents(5));
        idx=randperm(length(irain));
        for i=1:rainevents(2)-rainevents(3)
            mediumrain(i)=rain(irain(idx(i)));
        end
        mediumrain=[mediumrain intenserain1-1 intenserain1+1];
        mediumrain=unique(mediumrain);
        %remove these events from rain for further consideration
        for i=1:length(mediumrain)
            idx=find(rain==mediumrain(i));
            if isempty(idx)<1
                rain(i)=NaN;
            end
        end
        rain=rain(~isnan(rain));

        %low prec
        idx=randperm(length(rain));
        lowrain=zeros(1,length(rain));
        for i=1:length(rain)
            lowrain(i)=rain(idx(i));
        end
        lowrain=[lowrain intenserain-1 intenserain+1];
        lowrain=unique(lowrain);
        lowrain=lowrain(lowrain>0);
        % for i=1:length(intenserain1)
        %     lowrain=[lowrain intenserain1(i)-1 intenserain1(i)+1];
        % end
        % for i=1:length(intenserain)
        %     lowrain=[lowrain intenserain(i)-1 intenserain(i)+1];
        % end
        % lowrain=unique(lowrain);

        %loops for precipitation adjustment

        a=0.8; b=1.5;
        c1=a+(b-a)*rand(1);
        c2=a+(b-a)*rand(1);
        c3=a+(b-a)*rand(1);
        c4=a+(b-a)*rand(1);
        c5=a+(b-a)*rand(1);

        pintense1A=totalrainstat(ridx,17)*c1;
        pintenseA=totalrainstat(ridx,14)*c2;
        pmed1A=totalrainstat(ridx,11)*c3;
        pmedA=totalrainstat(ridx,8)*c4;
        plowA=totalrainstat(ridx,5)*c5;

        fit=0;
        counter=1;
        looping=length(intenserain1);
        lstart=looping;
        errortol=0.2;
        while fit<1
            a=max(totalrainstat(:,15))*1.2; b=totalrainstat(ridx,16);
            pintense1=a+(b-a)*rand(looping,1);
            if sum(pintense1)<pintense1A*(1+errortol) && sum(pintense1)>pintense1A*(1-errortol);
                fit=1;
                break
            else counter=counter+1;
            end
            if counter>3500 && looping>lstart*0.8
                errortol=errortol+0.02;
                counter=1;
            elseif counter>8000
                errortol=errortol+0.02;
                looping=looping-1;
                counter=1;
            end
        end

        fit=0;
        counter=1;
        looping=length(intenserain);
        lstart=looping;
        errortol=0.08;
        while fit<1
            a=totalrainstat(ridx,12); b=totalrainstat(ridx,13);
            pintense=a+(b-a)*rand(looping,1);
            if sum(pintense)<pintenseA*(1+errortol) && sum(pintense)>pintenseA*(1-errortol);
                fit=1;
                break
            else counter=counter+1;
            end
            if counter>2500 && looping>lstart*0.7
                errortol=errortol+0.02;
                counter=1;
            elseif counter>8000
                errortol=errortol+0.02;
                looping=looping-1;
                counter=1;
            end
        end


        fit=0;
        counter=1;
        looping=length(mediumrain1);
        lstart=looping;
        errortol=0.07;
        while fit<1
            a=totalrainstat(ridx,9); b=totalrainstat(ridx,10);
            pmed1=a+(b-a)*rand(looping,1);
            if sum(pmed1)<pmed1A*(1+errortol) && sum(pmed1)>pmed1A*(1-errortol);
                fit=1;
                break
            else counter=counter+1;
            end
            if counter>2500 && looping>lstart*0.7
                errortol=errortol+0.02;
                counter=1;
            elseif counter>8000
                errortol=errortol+0.02;
                looping=looping-1;
                counter=1;
            end
        end

        fit=0;
        counter=1;
        looping=length(mediumrain);
        lstart=looping;
        errortol=0.07;
        while fit<1
            a=totalrainstat(ridx,6); b=totalrainstat(ridx,7);
            pmed=a+(b-a)*rand(looping,1);
            if sum(pmed)<pmedA*(1+errortol) && sum(pmed)>pmedA*(1-errortol);
                fit=1;
                break
            else counter=counter+1;
            end
            if counter>2500 && looping>lstart*0.7
                errortol=errortol+0.02;
                counter=1;
            elseif counter>8000
                errortol=errortol+0.02;
                looping=looping-1;
                counter=1;
            end
        end


        fit=0;
        counter=1;
        looping=length(lowrain);
        lstart=looping;
        errortol=0.06;
        while fit<1
            a=totalrainstat(ridx,3); b=totalrainstat(ridx,4);
            plow=a+(b-a)*rand(looping,1);
            if sum(plow)<plowA*(1+errortol) && sum(plow)>plowA*(1-errortol);
                fit=1;
                break
            else counter=counter+1;
            end
            if counter>2500 && looping>lstart*0.7
                errortol=errortol+0.02;
                counter=1;
            elseif counter>8000
                errortol=errortol+0.02;
                looping=looping-1;
                counter=1;
            end
        end

        %give back rain events
        precipitation=zeros(1,365);
        a=randperm(length(pintense1));
        ir=0;
        for i=1:length(pintense1)
            ir=ir+1;
            while isnan(intenserain1(ir)) && ir<=i
                ir=ir+1;
            end
            if isnan(intenserain1(ir))<1
                precipitation(intenserain1(ir))=pintense1(a(i));
            end
        end
        a=randperm(length(pintense));
        ir=0;
        for i=1:length(pintense)
            ir=ir+1;
            while isnan(intenserain(ir)) && ir<=i
                ir=ir+1;
            end
            if isnan(intenserain(ir))<1
                precipitation(intenserain(ir))=pintense(a(i));
            end
        end
        a=randperm(length(pmed1));
        ir=0;
        for i=1:length(pmed1)
            ir=ir+1;
            while isnan(mediumrain1(ir)) && ir<=i
                ir=ir+1;
            end
            if isnan(mediumrain1(ir))<1
                precipitation(mediumrain1(ir))=pmed1(a(i));
            end
        end
        a=randperm(length(pmed));
        ir=0;
        for i=1:length(pmed)
            ir=ir+1;
            while isnan(mediumrain(ir)) && ir<=i
                ir=ir+1;
                if ir>length(mediumrain)
                    ir=1;
                end
            end
            if isnan(mediumrain(ir))<1
                precipitation(mediumrain(ir))=pmed(a(i));
            end
        end
        a=randperm(length(plow));
        ir=0;
        for i=1:length(plow)
            ir=ir+1;
            while isnan(lowrain(ir)) && ir<=i
                ir=ir+1;
            end
            if isnan(lowrain(ir))<1
                precipitation(lowrain(ir))=plow(a(i));
            end
        end


        %'''''''''''''''''''''''''''''''''''''''''''''''''''''''



        %weather
        temperature=zeros(3,365);
        humidity=zeros(1,365);
        for i=1:365
            idx=find(indore(:,12)==i);
            dummy=abs(indore(idx,7)-precipitation(i));
            for j=1:length(idx)
                if idx(j)==1
                    idx(j)=2;
                end
            end
            dummy1=abs(indore(idx-1,7)-precipitation(i));
            for j=1:length(idx)
                if idx(j)==max(idx)
                    idx(j)=max(idx)-1;
                end
            end
            dummy2=abs(indore(idx+1,7)-precipitation(i));
            idxi=find(dummy==min(dummy));
            idxi1=find(dummy1==min(dummy1));
            idxi2=find(dummy2==min(dummy2));
            a=zeros(1,length(idxi));
            clear b c
            for j=1:length(idxi)
                b=find(idxi1==idxi(j));
                if isnan(b)<1 | isempty(b)<1
                    a(j)=1;
                end
                b=find(idxi2==idxi(j));
                if isnan(b)<1 | isempty(b)<1
                    a(j)=a(j)+1;
                end
            end
            c=find(a==max(a));
            if length(c)>1
                b=randperm(length(c));
                idxx=idxi(c(b(1)));
            else idxx=idxi(c);
            end
            temperature(1,i)=indore(idx(idxx),4);
            temperature(2,i)=indore(idx(idxx),5);
            humidity(i)=indore(idx(idxx),6);
        end

        if isnan(humidity(1))
            humidity(1)=humidity(2);
        elseif isnan(humidity(365))
            humidity(365)=humidity(364);
        end
        for i=2:364
            if sum(isnan(humidity(i-1:i+1)))>0
                ir=1;
                while isnan(humidity(i)) && ir<5
                    humidity(ir)=mean([humidity(i-1) humidity(i+ir)]);
                    ir=ir+1;
                end
            end
        end

        %transfer results into weather matrix
        clear aa ab ac ad ae
        if ii<2
            aa=[((1:365)+(ii-1)*365)];
            ab=[temperature(1,:)];
            ac=[temperature(2,:)];
            ad=[humidity(:)];
            ae=[precipitation(:)];
        else
            aa=[weather(1,:) ((1:365)+(ii-1)*365)];
            ab=[weather(2,:) temperature(1,:)];
            ac=[weather(3,:) temperature(2,:)];
            ad=[weather(4,:) humidity(:)'];
            ae=[weather(5,:) precipitation(:)'];
            clear weather
        end
        weather(1,:)=aa';
        weather(2,:)=ab';
        weather(3,:)=ac';
        weather(4,:)=ad';
        weather(5,:)=ae';

    end

    %check NaNs
    for iw=1:5
        if sum(isnan(weather(iw,:)))>0
            idx=find(isnan(weather(iw,:)));
            for i=1:length(idx)
                if idx(i)>2 && idx(i)<length(weather(iw,:))-1
                    dummy=weather(iw,idx(i)-2:idx(i)+1);
                    dummy1=mean(dummy(~isnan(dummy)));
                elseif idx(i)<3
                    dummy=weather(iw,idx(i):idx(i)+4);
                    dummy1=mean(dummy(~isnan(dummy)));
                end
                weather(iw,idx(i))=dummy1;
            end
        end
    end

    figure(5)
    plot(weather(5,:))
    hold on
    plot(weather(2,:),'Color','magenta')
    plot(weather(3,:),'Color','cyan')
    plot(weather(4,:),'Color','yellow')


    %''''''''''''''''''''''''''''''''''''''''''''''''''''''''

    %CHECK STATISTICS AGAIN WITH SAME BAND ROUTINE FROM ABOVE
    %''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
    %BAND of reasonable data calculation
    %get bounds
    for i=1:365
        clear idxx idx
        for ix=1:noyears
            idx(ix)=i+365*(ix-1);
        end

        pEx(i)=length(idx);%only to scale prec likeliness according to years reagarded

        Btmaxd(i,1)=max(weather(2,idx));
        Btmaxd(i,2)=min(weather(2,idx));
        Btmaxd(i,3)=mean(weather(2,idx));
        if isnan(Btmaxd(i,3))
            disp('nan error t(max)')
        end

        Btmind(i,1)=max(weather(3,idx));
        Btmind(i,2)=min(weather(3,idx));
        Btmind(i,3)=mean(weather(3,idx));
        if isnan(Btmind(i,3))
            disp('nan error t(min)')
        end

        clear tmeandummy
        for j=1:length(idx)
            tmeandummy(j)=mean([weather(2,idx(j)) weather(3,idx(j))]);
        end
        Btmd(i,1)=max(tmeandummy);
        Btmd(i,2)=min(tmeandummy);
        Btmd(i,3)=mean(tmeandummy);
        if isnan(Btmd(i,3))
            disp('nan error t(mean)')
        end

        Bhumidd(i,1)=max(weather(4,idx));
        Bhumidd(i,2)=min(weather(4,idx));
        Bhumidd(i,3)=mean(weather(4,idx));
        if isnan(Bhumidd(i,3))
            disp('nan error humid')
        end

        if max(isempty(idx))<1 && max(isnan(idx))<1
            Braind(i,1)=max(weather(5,idx));
            Braind(i,2)=min(weather(5,idx));
            Braind(i,3)=mean(weather(5,idx));
            Braind(i,4)=0;
            for ic=1:length(idx)
                if weather(5,idx(ic))>0
                    Braind(i,4)=Braind(i,4)+1;
                end
            end
            if isnan(Braind(i,4))
                disp('nan error rain')
            end
        else Braind(i,:)=0;
        end

    end

    for rep=1:5
        for i=6:361
            Btmaxd(i,1)=mean(Btmaxd(i-5:i+5,1));
            Btmaxd(i,2)=mean(Btmaxd(i-5:i+5,2));
            Btmaxd(i,3)=mean(Btmaxd(i-5:i+5,3));
            Btmind(i,1)=mean(Btmind(i-5:i+5,1));
            Btmind(i,2)=mean(Btmind(i-5:i+5,2));
            Btmind(i,3)=mean(Btmind(i-5:i+5,3));
            Btmd(i,1)=mean(Btmd(i-5:i+5,1));
            Btmd(i,2)=mean(Btmd(i-5:i+5,2));
            Btmd(i,3)=mean(Btmd(i-5:i+5,3));
            Bhumidd(i,1)=mean(Bhumidd(i-5:i+5,1));
            Bhumidd(i,2)=mean(Bhumidd(i-5:i+5,2));
            Bhumidd(i,3)=mean(Bhumidd(i-5:i+5,3));
            Braind(i,1)=mean(Braind(i-5:i+5,1));
            Braind(i,2)=mean(Braind(i-5:i+5,2));
            Braind(i,3)=mean(Braind(i-5:i+5,3));
            Braind(i,4)=mean(Braind(i-5:i+5,4));
        end

        superix=[356 357 358 359 360 361 362 363 364 365 366 1 2 3 4 5 6 7 8 9 10];
        for j=1:10
            ix=superix(j:j+10);
            Btmaxd(ix(6),1)=mean(Btmaxd(ix,1));
            Btmaxd(ix(6),2)=mean(Btmaxd(ix,2));
            Btmaxd(ix(6),3)=mean(Btmaxd(ix,3));
            Btmind(ix(6),1)=mean(Btmind(ix,1));
            Btmind(ix(6),2)=mean(Btmind(ix,2));
            Btmind(ix(6),3)=mean(Btmind(ix,3));
            Btmd(ix(6),1)=mean(Btmd(ix,1));
            Btmd(ix(6),2)=mean(Btmd(ix,2));
            Btmd(ix(6),3)=mean(Btmd(ix,3));
            Bhumidd(ix(6),1)=mean(Bhumidd(ix,1));
            Bhumidd(ix(6),2)=mean(Bhumidd(ix,2));
            Bhumidd(ix(6),3)=mean(Bhumidd(ix,3));
            Braind(ix(6),1)=mean(Braind(ix,1));
            Braind(ix(6),2)=mean(Braind(ix,2));
            Braind(ix(6),3)=mean(Braind(ix,3));
            Braind(ix(6),4)=mean(Braind(ix,4));
        end
    end

    for i=3:364
        Btmax(i,1)=median(Btmaxd(i-2:i+2,1));
        Btmax(i,2)=median(Btmaxd(i-2:i+2,2));
        Btmax(i,3)=median(Btmaxd(i-2:i+2,3));
        Btmin(i,1)=median(Btmind(i-2:i+2,1));
        Btmin(i,2)=median(Btmaxd(i-2:i+2,2));
        Btmin(i,3)=median(Btmaxd(i-2:i+2,3));
        Btm(i,1)=median(Btmd(i-2:i+2,1));
        Btm(i,2)=median(Btmd(i-2:i+2,2));
        Btm(i,3)=median(Btmd(i-2:i+2,3));
        Bhumid(i,1)=median(Bhumidd(i-2:i+2,1));
        Bhumid(i,2)=median(Bhumidd(i-2:i+2,2));
        Bhumid(i,3)=median(Bhumidd(i-2:i+2,3));
        Brain(i,1)=median(Braind(i-2:i+2,1));
        Brain(i,2)=median(Braind(i-2:i+2,2));
        Brain(i,3)=median(Braind(i-2:i+2,3));
        Brain(i,4)=median(Braind(i-2:i+2,4));
    end

    for j=1:4
        if j==1
            ix=[365 366 1 2 3];
        elseif j==2
            ix=[366 1 2 3 4];
        elseif j==3
            ix=[364 365 366 1 2];
        elseif j==4
            ix=[363 364 365 366 1];
        end

        Btmax(ix(3),1)=median(Btmaxd(ix,1));
        Btmax(ix(3),2)=median(Btmaxd(ix,2));
        Btmax(ix(3),3)=median(Btmaxd(ix,3));
        Btmin(ix(3),1)=median(Btmind(ix,1));
        Btmin(ix(3),2)=median(Btmind(ix,2));
        Btmin(ix(3),3)=median(Btmind(ix,3));
        Btm(ix(3),1)=median(Btmd(ix,1));
        Btm(ix(3),2)=median(Btmd(ix,2));
        Btm(ix(3),3)=median(Btmd(ix,3));
        Bhumid(ix(3),1)=median(Bhumidd(ix,1));
        Bhumid(ix(3),2)=median(Bhumidd(ix,2));
        Bhumid(ix(3),3)=median(Bhumidd(ix,3));
        Brain(ix(3),1)=median(Braind(ix,1));
        Brain(ix(3),2)=median(Braind(ix,2));
        Brain(ix(3),3)=median(Braind(ix,3));
        Brain(ix(3),4)=median(Braind(ix,4));
    end
    Brain(:,4)=Brain(:,4)/median(pEx);

    figure(4)
    subplot(2,3,1)
    hold off
    plot(Btmax(:,1))
    hold on
    plot(Btmax(:,2))
    plot(Btmax(:,3),'Color','black')
    title('T max')

    subplot(2,3,2)
    hold off
    plot(Btmin(:,1))
    hold on
    plot(Btmin(:,2))
    plot(Btmin(:,3),'Color','black')
    title('T min')

    subplot(2,3,3)
    hold off
    plot(Btm(:,1))
    hold on
    plot(Btm(:,2))
    plot(Btm(:,3),'Color','black')
    title('T mean')

    subplot(2,3,4)
    hold off
    plot(Bhumid(:,1))
    hold on
    plot(Bhumid(:,2))
    plot(Bhumid(:,3),'Color','black')
    title('Humid')

    subplot(2,3,5)
    hold off
    plot(Brain(:,1))
    hold on
    plot(Brain(:,2))
    plot(Brain(:,3),'Color','black')
    title('Rain')

    subplot(2,3,6)
    hold off
    plot(Brain(:,4))
    title('Rain Likeliness')


%########################################################
%###############   OUTPUT TO FILES      #################
%########################################################
%''''''''''''''''''''''''''''''''''''''''''''''''''''''''

    %date generation
    leapy=0;
    i=0;
    j=0;
    k=0;
    while j<1
        i=i+1;
        k=k+1;
        if i==length(weather(1,:))
            j=1;
            break
        end
        a=datenum('1 1 2000')+(k-1);
        if str2num(datestr(a,'mm dd'))==[2 29]
            leapy=1;
        end
        weatherx(2:5,k)=weather(2:5,i);
        weatherx(1,k)=a;
        if leapy==1 && sum(str2num(datestr(a,'mm dd'))==[12 30])==2
            k=k+1;
            %check this. maybe better use two indices
            weatherx(2:5,k)=weather(2:5,i);
            weatherx(1,k)=datenum('1 1 2000')+(k-1);
            leapy=0;
        end
    end

    %####TEMPERATURE.DAT######
    fid=fopen(['./generated',num2str(iii),'/temperature.dat'],'w+');
    fprintf(fid,'Daily average temperature (in degrees Celcius) for each subbasin, ordered according to Map-IDs\n');
    fprintf(fid,'Date	No. of days');
    for j=1:length(subs(:,1))
        fprintf(fid,', Subbasin_ID');
    end
    fprintf(fid,'\n');
    fprintf(fid,'0	0	');
    for j=1:length(subs(:,1))
        fprintf(fid,[num2str(subs(j,1)),'	']);
    end
    fprintf(fid,'\n');

    m=length(weatherx(1,:));
    xstart=weatherx(1,1);
    xend=weatherx(1,length(weatherx(1,:)));
    for i=1:m
        fwrite(fid,[datestr(weatherx(1,i),'ddmmyyyy'),'    ',num2str(i),' ']);
        pdummy=([num2str(mean([weatherx(2,i) weatherx(3,i)]),'%.1f'),'  ']);
        for j=1:length(subs(:,1))
            fwrite(fid,pdummy);
        end
        fprintf(fid,'\n');
    end
    fclose(fid);

    %MAX TEMP
    fid=fopen(['./generated',num2str(iii),'/tmax.dat'],'w+');
    fprintf(fid,'Daily max temperature (in degrees Celcius) for each subbasin, ordered according to Map-IDs\n');
    fprintf(fid,'Date	No. of days');
    for j=1:length(subs(:,1))
        fprintf(fid,', Subbasin_ID');
    end
    fprintf(fid,'\n');
    fprintf(fid,'0	0	');
    for j=1:length(subs(:,1))
        fprintf(fid,[num2str(subs(j,1)),'	']);
    end
    fprintf(fid,'\n');
    
    for i=1:m
        fwrite(fid,[datestr(weatherx(1,i),'ddmmyyyy'),'    ',num2str(i),' ']);
        pdummy=([num2str(weatherx(2,i),'%.1f'),'  ']);
        for j=1:length(subs(:,1))
            fwrite(fid,pdummy);
        end
        fprintf(fid,'\n');
    end
    fclose(fid);

    %MIN TEMP
    fid=fopen(['./generated',num2str(iii),'/tmin.dat'],'w+');
    fprintf(fid,'Daily min temperature (in degrees Celcius) for each subbasin, ordered according to Map-IDs\n');
    fprintf(fid,'Date	No. of days');
    for j=1:length(subs(:,1))
        fprintf(fid,', Subbasin_ID');
    end
    fprintf(fid,'\n');
    fprintf(fid,'0	0	');
    for j=1:length(subs(:,1))
        fprintf(fid,[num2str(subs(j,1)),'	']);
    end
    fprintf(fid,'\n');

    for i=1:m
        fwrite(fid,[datestr(weatherx(1,i),'ddmmyyyy'),'    ',num2str(i),' ']);

        if isnan(weatherx(3,i))
            weatherx(3,i)=mean([weather(3,i+1) weatherx(3,i-1)]);
        end
        pdummy=([num2str(weatherx(3,i),'%.1f'),'  ']);
        for j=1:length(subs(:,1))
            fwrite(fid,pdummy);
        end
        fprintf(fid,'\n');
    end
    fclose(fid);


    %####RAIN_DAILY.DAT########
    fid=fopen(['./generated',num2str(iii),'/rain_daily.dat'],'w+');
    fprintf(fid,'Daily average precipitation [mm/d] for each subbasin, ordered according to Map-IDs\n');
    fprintf(fid,'Date	No. of days');
    for j=1:length(subs(:,1))
        fprintf(fid,', Subbasin_ID');
    end
    fprintf(fid,'\n');
    fprintf(fid,'0	0	');
    for j=1:length(subs(:,1))
        fprintf(fid,[num2str(subs(j,1)),'	']);
    end
    fprintf(fid,'\n');

    for i=1:m
        fwrite(fid,[datestr(weatherx(1,i),'ddmmyyyy'),'    ',num2str(i),' ']);

        if isnan(weatherx(5,i))
            weatherx(5,i)=mean([weather(5,i+1) weatherx(5,i-1)]);
        end
        pdummy=([num2str(weatherx(5,i),'%.1f'),'  ']);
        for j=1:length(subs(:,1))
            fwrite(fid,pdummy);
        end
        fprintf(fid,'\n');
    end
    fclose(fid);



    %####HUMIDITY.DAT########
    fid=fopen(['./generated',num2str(iii),'/humidity.dat'],'w+');
    fprintf(fid,'Daily average humidity [in per cent] for each subbasin, ordered according to Map-IDs\n');
    fprintf(fid,'Date	No. of days');
    for j=1:length(subs(:,1))
        fprintf(fid,', Subbasin_ID');
    end
    fprintf(fid,'\n');
    fprintf(fid,'0	0	');
    for j=1:length(subs(:,1))
        fprintf(fid,[num2str(subs(j,1)),'	']);
    end
    fprintf(fid,'\n');

    for i=1:m
        fwrite(fid,[datestr(weatherx(1,i),'ddmmyyyy'),'    ',num2str(i),' ']);
        if isnan(weatherx(4,i))
            dummy=weather(4,i+1:i-1);
            dummy1=mean(dummy(~isnan(dummy)));
            weatherx(4,i)=dummy1;
        end
        pdummy=([num2str(weatherx(4,i),'%.1f'),'  ']);
        for j=1:length(subs(:,1))
            fwrite(fid,pdummy);
        end
        fprintf(fid,'\n');
    end
    fclose(fid);

    %####RADIATION.DAT########
    fid=fopen(['./generated',num2str(iii),'/radiation.dat'],'w+');
    fprintf(fid,'Daily average shortwave radiation [in W/m2] for each subbasin, ordered according to Map-IDs\n');
    fprintf(fid,'Date	No. of days');
    for j=1:length(subs(:,1))
        fprintf(fid,', Subbasin_ID');
    end
    fprintf(fid,'\n');
    fprintf(fid,'0	0	');
    for j=1:length(subs(:,1))
        fprintf(fid,[num2str(subs(j,1)),'	']);
    end
    fprintf(fid,'\n');

    %incoming shortwave radiation
    LAT=22.4;
    S=1370;%W/m^2; Kyle 1985

    % ## CALCULATION OF LOOK-UP TABLE FOR S0 #####
    %S0 = Extraterrestial Radiation in MJ*m^2*d^1 for one year
    d=1;
    for d=1:365
        decl = 0.4093 * sin(((2*pi)/365)*d - 1.405);
        dr = 1 + 0.033 * cos((2*pi)/(365*d));
        t= acos(-tan(LAT) * tan(decl));
        S0(d)= 15.392 * dr * (t * sin(LAT) * sin(decl) + cos(LAT) * cos(decl) * sin(t));
    end

    for i=1:m
        x=datestr(weatherx(1,i),'yyyy');
        day=weatherx(1,i)-datenum(['1 1 ',datestr(weatherx(1,i),'yyyy')])+1;
        if day>365
            day=365;
        end
        fwrite(fid,[datestr(weatherx(1,i),'ddmmyyyy'),'    ',num2str(i),' ']);
        pdummy=([num2str((S0(day)*-1e06)/86400,'%.1f'),'  ']);
        for j=1:length(subs(:,1))
            fwrite(fid,pdummy);
        end
        fprintf(fid,'\n');
    end
    fclose(fid);


    %###RAINY_SEASON.DAT#########
    %use floating windows to scan all considered years
    %use jhabua station as reference
    for i=1:noyears
        %find monsoon onset
        idx=find(weatherx(1,:)==datenum(1999+i, 4, 30),1);
        if isempty(idx)
            disp('no idx found')
        end
        rainswitch=0;
        raintotal=0;
        while rainswitch<2 && raintotal<60
            idx=idx+1;
            rainswitchx=zeros(1,10);
            if idx
                for j=1:10
                    %if jhabua(idx+(j-1),4)>0
                    rainswitchx(j)=weatherx(5,idx+(j-1))/weatherx(5,idx+(j-1));
                    if isnan(rainswitchx(j))
                        rainswitchx(j)=0;
                    end
                    %else rainswitchx=0;
                    %end
                end
            end
            rainswitch=sum(rainswitchx);
            raintotal=sum(weatherx(5,idx:idx+9));
            if rainswitch>1 && raintotal>60
                disp('ONSET FOUND')
                break
            end
        end
        mset(i,1)=weatherx(1,idx+9)-datenum(1999+i, 1, 1);%onset day

        %find monsoon offset
        idx=find(weatherx(1,:)==datenum(1999+i, 11, 30),1);
        if isempty(idx)
            disp('no idx found')
        end
        rainswitch=0;
        raintotal=0;
        while rainswitch<1 && raintotal<20
            rainswitchx=zeros(1,10);
            if idx
                idx=idx-1;
                for j=1:10
                    rainswitchx(j)=weatherx(5,idx-(j-1))/weatherx(5,idx-(j-1));
                    if isnan(rainswitchx(j))
                        rainswitchx(j)=0;
                    end
                end
            end
            rainswitch=sum(rainswitchx);
            raintotal=sum(weatherx(5,idx:idx-9));
            if rainswitch>1 && raintotal>20
                break
            end
        end
        mset(i,2)=weatherx(1,idx-9)-datenum(1999+i, 1, 1);%offset day
    end


    fid=fopen(['./generated',num2str(iii),'/rainy_season.dat'],'w+');
    fprintf(fid,'Specification of the rainy season (per year)\n');
    fprintf(fid,'for the interpolation of temporal distribution of vegetation characteristics (Rootdepth,height,lai,albedo)\n');
    fprintf(fid,'Subbasin	Year    (Start-30)  Startday    Endday  (End+30)\n');
    for j=1:noyears
        for i=1:length(subs)
            fprintf(fid,[num2str(subs(i),'%.0f'),'   ',num2str(1999+j,'%.0f'),'    ',num2str(mset(j,1)-30,'%.0f'),'    ',num2str(mset(j,1),'%.0f'),'    ',num2str(mset(j,2)-30,'%.0f'),'    ',num2str(mset(j,2)+30,'%.0f'),'\n']);
        end
    end
    fclose(fid);

    
toc
disp(['run no.',num2str(iii),' done. check files for errors before transferring.'])
end

profile viewer
profile off